set echo on
spool trac_body.log
create or replace package body nl_trac_extract as
  procedure write_tables is
  -- pre: all tables have been expunged and redacted
  -- post:  44 ASCII files written to designated location
    procedure write_gs_agent is
    -- pre:  data in GS_AGENT is expunged
    -- post:  ASCII file table_gs_assignment.txt written to OS directory in file format specified by requirements
    begin -- write_gs_agent
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                                      'gs_agent.txt',
                                                      'w',
                                                      redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_AGENT';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
                        rpad ( decode ( salutation, null, ' ', redaction_pkg.c_mask ), 8, ' ' ) salutation,
                        rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) last_name,
                        rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
                        rpad ( decode ( title, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) title,
			rpad ( decode ( phone, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) phone,
                        rpad ( decode ( fax, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) fax,
                        rpad ( decode ( pager, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) pager,
                        rpad ( decode ( lead_agent, null, ' ', lead_agent ), 1, ' ' ) lead_agent,
 			rpad ( decode ( email, null, ' ', redaction_pkg.c_mask ), 100, ' ' ) email,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_agent
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.salutation );
          utl_file.put ( redaction_pkg.v_file_header, x.last_name );
          utl_file.put ( redaction_pkg.v_file_header, x.first_name );
          utl_file.put ( redaction_pkg.v_file_header, x.title );
          utl_file.put ( redaction_pkg.v_file_header, x.phone );
          utl_file.put ( redaction_pkg.v_file_header, x.fax );
          utl_file.put ( redaction_pkg.v_file_header, x.pager );
          utl_file.put ( redaction_pkg.v_file_header, x.lead_agent );
   	  utl_file.put ( redaction_pkg.v_file_header, x.email );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_agent;
    procedure write_gs_also_known is
    -- pre:  data in GS_ALSO_KNOWN is expunged
    -- post:  ASCII file table_gs_assignment.txt written to OS directory in file format specified by requirements
    begin -- write_gs_also_known
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_also_known.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_ALSO_KNOWN';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
                        rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 60, ' ' ) last_name,
                        rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
                        rpad ( decode ( last_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) last_sounds,
                        rpad ( decode ( first_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) first_sounds,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_also_known
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.last_name );
          utl_file.put ( redaction_pkg.v_file_header, x.first_name );
          utl_file.put ( redaction_pkg.v_file_header, x.last_sounds );
          utl_file.put ( redaction_pkg.v_file_header, x.first_sounds );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_also_known;
    procedure write_gs_archive_case is
    -- pre:  data in GS_ARCHIVE_CASE is expunged
    -- post:  ASCII file table_gs_archive_case.txt written to OS directory in file format specified by requirements
    begin -- write_gs_archive_case
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_archive_case.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_ARCHIVE_CASE';
      for x in ( select rpad ( decode ( aC.district, null, ' ', aC.district ), 10, ' ' ) district,
                        rpad ( decode ( id, null, ' ', id ), 10, ' ' ) id,
                        rpad ( decode ( class, null, ' ', class ), 1, ' ' ) class,
                        rpad ( decode ( name, null, ' ', redaction_pkg.c_mask ), 50, ' ' ) name,
                        rpad ( decode ( recvd_date, null, ' ', to_char ( recvd_date, 'DD-MON-YYYY' ) ), 11, ' ' ) recvd_date,
                        rpad ( decode ( us_role, null, ' ', us_role ), 2, ' ' ) us_role,
                        rpad ( decode ( lead_charge, null, ' ',
                                                     decode ( rcl1.process_name || rcl2.process_name, null, lead_charge,
                                                                                                      redaction_pkg.c_mask ) ), 25, ' ' ) lead_charge,
                        rpad ( decode ( prog_cat, null, ' ',
                                                  decode ( rcl1.process_name || rcl2.process_name, null, prog_cat,
                                                                                                   redaction_pkg.c_mask ) ), 3, ' ' ) prog_cat,
                        rpad ( decode ( cause_act, null, ' ', cause_act ), 4, ' ' ) cause_act,
                        rpad ( decode ( branch, null, ' ', branch ), 3, ' ' ) branch,
                        rpad ( decode ( comments, null, ' ', redaction_pkg.c_mask ), 60, ' ' ) comments,
                        rpad ( decode ( court, null, ' ', court ), 2, ' ' ) court,
                        rpad ( decode ( location, null, ' ', location ), 2, ' ' ) location,
                        rpad ( decode ( court_number, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) court_number,
                        rpad ( decode ( filing_date, null, ' ',
                                                     decode ( rcl1.process_name, null, to_char ( filing_date, 'DD-MON-YYYY' ),
                                                                                 redaction_pkg.c_mask ) ), 11, ' ' ) filing_date,
                        rpad ( decode ( service_date, null, ' ', to_char ( service_date, 'DD-MON-YYYY' ) ), 11, ' ' ) service_date,
                        rpad ( decode ( disposition, null, ' ', disposition ), 2, ' ' ) disposition,
                        rpad ( decode ( disp_reason, null, ' ', disp_reason ), 4, ' ' ) disp_reason,
                        rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
                        rpad ( decode ( inst_type, null, ' ',
                                                   decode ( rcl1.process_name, null, inst_type,
                                                                               redaction_pkg.c_mask ) ), 2, ' ' ) inst_type,
                        rpad ( decode ( inst_file_date, null, ' ',
                                                        decode ( rcl1.process_name, null, to_char ( inst_file_date, 'DD-MON-YYYY' ),
                                                                                    redaction_pkg.c_mask ) ), 11, ' ' ) inst_file_date,
                        rpad ( decode ( ausa_last_name, null, ' ', ausa_last_name ), 30, ' ' ) ausa_last_name,
                        rpad ( decode ( ausa_first_name, null, ' ', ausa_first_name ), 30, ' ' ) ausa_first_name,
                        rpad ( decode ( agency, null, ' ', agency ), 4, ' ' ) agency,
                        rpad ( decode ( to_char ( appeals_filed ), null, ' ', to_char ( appeals_filed ) ), 11, ' ' ) appeals_filed,
                        rpad ( decode ( store_num, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) store_num,
                        rpad ( decode ( dest_date, null, ' ', to_char ( dest_date, 'DD-MON-YYYY' ) ), 11, ' ' ) dest_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_archive_case ac,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where ac.district = rcl1.district(+) and
                        ac.id = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        ac.district = rcl2.district(+) and
                        ac.id = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by ac.district, id ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.id;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.class );
          utl_file.put ( redaction_pkg.v_file_header, x.name );
          utl_file.put ( redaction_pkg.v_file_header, x.recvd_date );
          utl_file.put ( redaction_pkg.v_file_header, x.us_role );
          utl_file.put ( redaction_pkg.v_file_header, x.lead_charge );
          utl_file.put ( redaction_pkg.v_file_header, x.prog_cat );
          utl_file.put ( redaction_pkg.v_file_header, x.cause_act );
          utl_file.put ( redaction_pkg.v_file_header, x.branch );
          utl_file.put ( redaction_pkg.v_file_header, x.comments );
          utl_file.put ( redaction_pkg.v_file_header, x.court );
          utl_file.put ( redaction_pkg.v_file_header, x.location );
          utl_file.put ( redaction_pkg.v_file_header, x.court_number );
          utl_file.put ( redaction_pkg.v_file_header, x.filing_date );
          utl_file.put ( redaction_pkg.v_file_header, x.service_date );
          utl_file.put ( redaction_pkg.v_file_header, x.disposition );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
          utl_file.put ( redaction_pkg.v_file_header, x.inst_type );
          utl_file.put ( redaction_pkg.v_file_header, x.inst_file_date );
          utl_file.put ( redaction_pkg.v_file_header, x.ausa_last_name );
          utl_file.put ( redaction_pkg.v_file_header, x.ausa_first_name );
          utl_file.put ( redaction_pkg.v_file_header, x.agency );
          utl_file.put ( redaction_pkg.v_file_header, x.appeals_filed );
          utl_file.put ( redaction_pkg.v_file_header, x.store_num );
          utl_file.put ( redaction_pkg.v_file_header, x.dest_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_archive_case;
    procedure write_gs_archive_part is
    -- pre:  data in GS_ARCHIVE_PART is expunged
    -- post:  ASCII file table_gs_archive_part.txt written to OS directory in file format specified by requirements
    begin -- write_gs_archive_part
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_archive_part.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_ARCHIVE_PART';
      for x in ( select rpad ( decode ( ap.caseid, null, ' ', ap.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( ap.district, null, ' ', ap.district ), 10, ' ' ) district,
                        rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 60, ' ' ) last_name,
                        rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
                        rpad ( decode ( last_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) last_sounds,
                        rpad ( decode ( first_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) first_sounds,
                        rpad ( decode ( role, null, ' ',
                                              decode ( rcl1.process_name || rcl2.process_name, null, role,
                                                                                               redaction_pkg.c_mask ) ), 2, ' ' ) role,
                        rpad ( decode ( disposition, null, ' ', disposition ), 2, ' ' ) disposition,
                        rpad ( decode ( disp_reason, null, ' ', disp_reason ), 4, ' ' ) disp_reason,
                        rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_archive_part ap,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where ap.district = rcl1.district(+) and
                        ap.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        ap.district = rcl2.district(+) and
                        ap.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by ap.district, ap.caseid ) loop
        begin
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.id;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.last_name );
          utl_file.put ( redaction_pkg.v_file_header, x.first_name );
          utl_file.put ( redaction_pkg.v_file_header, x.last_sounds );
          utl_file.put ( redaction_pkg.v_file_header, x.first_sounds );
          utl_file.put ( redaction_pkg.v_file_header, x.role );
          utl_file.put ( redaction_pkg.v_file_header, x.disposition );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_archive_part;
    procedure write_gs_assignment is
    -- pre:  data in GS_ASSIGMENT is expunged
    -- post:  ASCII file table_gs_assignment.txt written to OS directory in file format specified by requirements
    begin -- write_gs_assignment
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_assignment.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_ASSIGNMENT';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
                        rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( to_char ( staffid ), null, ' ', to_char ( staffid ) ), 10, ' ' ) staffid,
                        rpad ( decode ( position, null, ' ', position ), 1, ' ' ) position,
                        rpad ( decode ( start_date, null, ' ', to_char ( start_date, 'DD-MON-YYYY' ) ), 11, ' ' ) start_date,
                        rpad ( decode ( end_date, null, ' ', to_char ( end_date, 'DD-MON-YYYY' ) ), 11, ' ' ) end_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_assignment
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.staffid );
          utl_file.put ( redaction_pkg.v_file_header, x.position );
          utl_file.put ( redaction_pkg.v_file_header, x.start_date );
          utl_file.put ( redaction_pkg.v_file_header, x.end_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_assignment;
    -- subprocedures for write_tables
    procedure write_gs_case is
    -- pre:  data in GS_CASE is expunged and redacted
    -- post:  ASCII file table_gs_case.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE';
      for x in ( select rpad ( decode ( C.district, null, ' ', C.district ), 3, ' ' ) district,
                        rpad ( decode ( id, null, ' ', id ), 10, ' ' ) id,
                        rpad ( decode ( class, null, ' ', class ), 1, ' ' ) class,
                        rpad ( decode ( name, null, ' ', redaction_pkg.c_mask ), 50, ' ' ) name,
                        rpad ( decode ( recvd_date, null, ' ',
                                                    to_char ( recvd_date, 'DD-MON-YYYY' ) ), 11, ' ' ) recvd_date,
                        rpad ( decode ( security, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) security,
                        rpad ( decode ( priority, null, ' ',
                                                  decode ( rcl1.process_name || rcl2.process_name, null, priority,
                                                                                                   redaction_pkg.c_mask ) ), 1, ' ' ) priority,
                        rpad ( decode ( type, null, ' ',
                                              decode ( rcl1.process_name || rcl2.process_name, null, type,
                                                                                               redaction_pkg.c_mask ) ), 4, ' ' ) type,
                        rpad ( decode ( us_role, null, ' ', us_role ), 2, ' ' ) us_role,
                        rpad ( decode ( lit_resp, null, ' ', lit_resp ), 2, ' ' ) lit_resp,
                        rpad ( decode ( lit_track, null, ' ', lit_track ), 1, ' ' ) lit_track,
                        rpad ( decode ( weight, null, ' ', weight ), 2, ' ' ) weight,
                        rpad ( decode ( branch, null, ' ', branch ), 3, ' ' ) branch,
                        rpad ( decode ( grand_jury_num, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) grand_jury_num,
                        rpad ( decode ( unit, null, ' ', unit ), 4, ' ' ) unit,
                        rpad ( decode ( dcmns_number, null, ' ', dcmns_number ), 11, ' ' ) dcmns_number,
                        rpad ( decode ( tribe, null, ' ', tribe ), 4, ' ' ) tribe,
                        rpad ( decode ( reservation, null, ' ', reservation ), 4, ' ' ) reservation,
                        rpad ( decode ( spec_proj, null, ' ',
                                                   decode ( rcl1.process_name || rcl2.process_name, null, spec_proj,
                                                                                                    redaction_pkg.c_mask ) ), 2, ' ' ) spec_proj,
                        rpad ( decode ( vic_wit, null, ' ', vic_wit ), 1, ' ' ) vic_wit,
                        rpad ( decode ( adr_mode, null, ' ', adr_mode ), 2, ' ' ) adr_mode,
                        rpad ( decode ( collect_ind, null, ' ', collect_ind ), 1, ' ' ) collect_ind,
                        rpad ( decode ( offense_from, null, ' ',
                                                      to_char ( offense_from, 'DD-MON-YYYY' ) ), 11, ' ' ) offense_from,
                        rpad ( decode ( offense_to, null, ' ',
                                                    to_char ( offense_to, 'DD-MON-YYYY' ) ), 11, ' ' ) offense_to,
                        rpad ( decode ( lead_charge, null, ' ',
                                                     decode ( rcl1.process_name || rcl2.process_name, null, lead_charge,
                                                                                                      redaction_pkg.c_mask ) ), 25, ' ' ) lead_charge,
                        rpad ( decode ( physical_loc, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) physical_loc,
                        rpad ( decode ( store_num, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) store_num,
                        rpad ( decode ( civil_poten, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) civil_poten,
                        rpad ( decode ( sys_init_date, null, ' ',
                                                       to_char ( sys_init_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sys_init_date,
                        rpad ( decode ( access_date, null, ' ',
                                                     to_char ( access_date, 'DD-MON-YYYY' ) ), 11, ' ' ) access_date,
                        rpad ( decode ( status, null, ' ', status ), 1, ' ' ) status,
                        rpad ( decode ( close_date, null, ' ',
                                                    to_char ( close_date, 'DD-MON-YYYY' ) ), 11, ' ' ) close_date,
                        rpad ( decode ( dest_date, null, ' ',
                                                   to_char ( dest_date, 'DD-MON-YYYY' ) ), 11, ' ' ) dest_date,
                        rpad ( decode ( permanent, null, ' ', permanent ), 1, ' ' ) permanent,
                        rpad ( decode ( case_restricted, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) case_restricted,
                        rpad ( decode ( criminal_poten, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) criminal_poten,
                        rpad ( decode ( tot_victims, null, ' ', to_char ( tot_victims ) ), 11, ' ' ) tot_victims,
                        rpad ( decode ( related_flu_flag, null, ' ', related_flu_flag ), 1, ' ' ) related_flu_flag,
                        rpad ( decode ( qui_tam, null, ' ', qui_tam ), 1, ' ' ) qui_tam,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case c,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where c.district = rcl1.district(+) and
                        c.id = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        c.district = rcl2.district(+) and
                        c.id = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by c.district, id ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.id;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.class );
          utl_file.put ( redaction_pkg.v_file_header, x.name );
          utl_file.put ( redaction_pkg.v_file_header, x.recvd_date );
          utl_file.put ( redaction_pkg.v_file_header, x.security );
          utl_file.put ( redaction_pkg.v_file_header, x.priority );
          utl_file.put ( redaction_pkg.v_file_header, x.type );
          utl_file.put ( redaction_pkg.v_file_header, x.us_role );
          utl_file.put ( redaction_pkg.v_file_header, x.lit_resp );
          utl_file.put ( redaction_pkg.v_file_header, x.lit_track );
          utl_file.put ( redaction_pkg.v_file_header, x.weight );
          utl_file.put ( redaction_pkg.v_file_header, x.branch );
          utl_file.put ( redaction_pkg.v_file_header, x.grand_jury_num );
          utl_file.put ( redaction_pkg.v_file_header, x.unit );
          utl_file.put ( redaction_pkg.v_file_header, x.dcmns_number );
          utl_file.put ( redaction_pkg.v_file_header, x.tribe );
          utl_file.put ( redaction_pkg.v_file_header, x.reservation );
          utl_file.put ( redaction_pkg.v_file_header, x.spec_proj );
          utl_file.put ( redaction_pkg.v_file_header, x.vic_wit );
          utl_file.put ( redaction_pkg.v_file_header, x.adr_mode );
          utl_file.put ( redaction_pkg.v_file_header, x.collect_ind );
          utl_file.put ( redaction_pkg.v_file_header, x.offense_from );
          utl_file.put ( redaction_pkg.v_file_header, x.offense_to );
          utl_file.put ( redaction_pkg.v_file_header, x.lead_charge );
          utl_file.put ( redaction_pkg.v_file_header, x.physical_loc );
          utl_file.put ( redaction_pkg.v_file_header, x.store_num );
          utl_file.put ( redaction_pkg.v_file_header, x.civil_poten );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_init_date );
          utl_file.put ( redaction_pkg.v_file_header, x.access_date );
          utl_file.put ( redaction_pkg.v_file_header, x.status );
          utl_file.put ( redaction_pkg.v_file_header, x.close_date );
          utl_file.put ( redaction_pkg.v_file_header, x.dest_date );
          utl_file.put ( redaction_pkg.v_file_header, x.permanent );
          utl_file.put ( redaction_pkg.v_file_header, x.case_restricted );
          utl_file.put ( redaction_pkg.v_file_header, x.criminal_poten );
          utl_file.put ( redaction_pkg.v_file_header, x.tot_victims );
          utl_file.put ( redaction_pkg.v_file_header, x.related_flu_flag );
          utl_file.put ( redaction_pkg.v_file_header, x.qui_tam );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case;
    procedure write_gs_case_cause_act is
    -- pre:  data in GS_CASE_CAUSE_ACT is expunged
    -- post:  ASCII file table_gs_case_cause_act.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case_cause_act
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case_cause_act.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE_CAUSE_ACT';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( cause_act, null, ' ', cause_act ), 4, ' ' ) cause_act,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case_cause_act
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.cause_act );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case_cause_act;
    procedure write_gs_case_doj_div is
    -- pre:  data in GS_CASE_DOJ_DIV is expunged
    -- post:  ASCII file table_gs_case_doj_div.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case_doj_div
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case_doj_div.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE_DOJ_DIV';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( doj_div, null, ' ', doj_div ), 4, ' ' ) doj_div,
			rpad ( decode ( doj_number, null, ' ', doj_number ), 25, ' ' ) doj_number,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case_doj_div
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.doj_div );
	  utl_file.put ( redaction_pkg.v_file_header, x.doj_number );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case_doj_div;
    procedure write_gs_case_dom_terr_ind is
    -- pre:  data in GS_CASE_DOM_TERR_IND is expunged
    -- post:  ASCII file table_gs_case_dom_terr_ind.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case_dom_terr_ind
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case_dom_terr_ind.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE_DOM_TERR_IND';
      for x in ( select rpad ( decode ( cdti.district, null, ' ', cdti.district ), 10, ' ' ) district,
                        rpad ( decode ( cdti.caseid, null, ' ',
                                                     decode ( rcl1.process_name || rcl2.process_name, null, cdti.caseid,
                                                                                                      redaction_pkg.c_mask ) ), 10, ' ' ) caseid,
                        rpad ( decode ( id, null, ' ',
                                                  decode ( rcl1.process_name || rcl2.process_name, null, to_char ( id ),
                                                                                                   redaction_pkg.c_mask ) ), 10, ' ' ) id,
                        rpad ( decode ( dom_terr_ind, null, ' ',
                                                      decode ( rcl1.process_name || rcl2.process_name, null, dom_terr_ind,
                                                                                                       redaction_pkg.c_mask ) ), 2, ' ' ) dom_terr_ind,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case_dom_terr_ind cdti,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where cdti.district = rcl1.district(+) and
                        cdti.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        cdti.district = rcl2.district(+) and
                        cdti.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by cdti.district, cdti.caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.dom_terr_ind );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case_dom_terr_ind;
    procedure write_gs_case_prog_cat is
    -- pre:  data in GS_CASE_PROG_CAT is expunged
    -- post:  ASCII file table_gs_case_prog_cat.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case_doj_div
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case_prog_cat.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE_PROG_CAT';
      for x in ( select rpad ( decode ( cpc.district, null, ' ', cpc.district ), 10, ' ' ) district,
                        rpad ( decode ( cpc.caseid, null, ' ', cpc.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( prog_cat, null, ' ',
                                                  decode ( rcl1.process_name || rcl2.process_name, null, prog_cat,
                                                                                                   redaction_pkg.c_mask ) ), 3, ' ' ) prog_cat,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case_prog_cat cpc,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where cpc.district = rcl1.district(+) and
                        cpc.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        cpc.district = rcl2.district(+) and
                        cpc.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by cpc.district, cpc.caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.prog_cat );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case_prog_cat;
    procedure write_gs_case_special_proj is
    -- pre:  data in GS_CASE_SPECIAL_PROJ is expunged
    -- post:  ASCII file table_gs_case_special_proj.txt written to OS directory in file format specified by requirements
    begin -- write_gs_case_special_proj
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_case_special_proj.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CASE_SPECIAL_PROJ';
      for x in ( select rpad ( decode ( csp.district, null, ' ', csp.district ), 10, ' ' ) district,
                        rpad ( decode ( csp.caseid, null, ' ', csp.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( special_proj, null, ' ',
                                                      decode ( rcl1.process_name || rcl2.process_name, null, special_proj,
                                                                                                       redaction_pkg.c_mask ) ), 2, ' ' ) special_proj,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_case_special_proj csp,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where csp.district = rcl1.district(+) and
                        csp.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        csp.district = rcl2.district(+) and
                        csp.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by csp.district, csp.caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.special_proj );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_case_special_proj;
    procedure write_gs_comment is
    -- pre:  data in GS_COMMENT is expunged
    -- post:  ASCII file table_gs_comment.txt written to OS directory in file format specified by requirements
    begin -- write_gs_comment
      -- create base file
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_comment.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_COMMENT';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
                        rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id1 ), null, ' ', to_char ( id1 ) ), 10, ' ' ) id1,
                        rpad ( decode ( to_char ( id2 ), null, ' ', to_char ( id2 ) ), 10, ' ' ) id2,
                        rpad ( decode ( category, null, ' ', category ), 1, ' ' ) category,
                        rpad ( decode ( text, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) text,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_comment
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id1 );
	  utl_file.put ( redaction_pkg.v_file_header, x.id2 );
	  utl_file.put ( redaction_pkg.v_file_header, x.category );
	  utl_file.put ( redaction_pkg.v_file_header, x.text );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_comment;
    procedure write_gs_cont_services is
    -- pre:  data in GS_CONT_SERVICES is expunged
    -- post:  ASCII file table_gs_cont_services.txt written to OS directory in file format specified by requirements
    begin -- write_gs_cont_services
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_cont_services.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CONT_SERVICES';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', redaction_pkg.c_mask ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( contid ), null, ' ', to_char ( contid ) ), 10, ' ' ) contid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( to_char ( serv_agency ), null, ' ', redaction_pkg.c_mask ), 11, ' ' ) serv_agency,
			rpad ( decode ( serv_type, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) serv_type ,
			rpad ( decode ( serv_language, null, ' ', redaction_pkg.c_mask ), 3, ' ' ) serv_language,
			rpad ( decode ( serv_special, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) serv_special,
                        partid partid_err,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_cont_services
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid_err;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.contid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.serv_agency );
	  utl_file.put ( redaction_pkg.v_file_header, x.serv_type );
	  utl_file.put ( redaction_pkg.v_file_header, x.serv_language );
	  utl_file.put ( redaction_pkg.v_file_header, x.serv_special );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_cont_services;
    procedure write_gs_contact_log is
    -- pre:  data in GS_CONTACT_LOG is expunged
    -- post:  ASCII file table_gs_contact_log.txt written to OS directory in file format specified by requirements
    begin -- write_gs_contact_log
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_contact_log.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CONTACT_LOG';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', redaction_pkg.c_mask ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( cont_date, null, ' ', to_char ( cont_date, 'DD-MON-YYYY' ) ), 11, ' ' ) cont_date,
			rpad ( decode ( purpose, null, ' ', redaction_pkg.c_mask ), 2, ' ' ) purpose,
			rpad ( decode ( type, null, ' ', redaction_pkg.c_mask ), 2, ' ' ) type,
			rpad ( decode ( initiator, null, ' ', redaction_pkg.c_mask ), 2, ' ' ) initiator,
			rpad ( decode ( to_char ( staffid ), null, ' ', redaction_pkg.c_mask ), 10, ' ' ) staffid,
			rpad ( decode ( doc_code, null, ' ', redaction_pkg.c_mask ), 3, ' ' ) doc_code,
                        partid partid_err,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_contact_log
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid_err;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.cont_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.purpose );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.initiator );
	  utl_file.put ( redaction_pkg.v_file_header, x.staffid );
	  utl_file.put ( redaction_pkg.v_file_header, x.doc_code );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_contact_log;
    procedure write_gs_control_sub is
    -- pre:  data in GS_CONTROL_SUB is expunged
    -- post:  ASCII file table_gs_control_sub.txt written to OS directory in file format specified by requirements
    begin -- write_gs_control_sub
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_control_sub.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_CONTROL_SUB';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( type, null, ' ', type ), 1, ' ' ) type,
			rpad ( decode ( to_char ( quantity ), null, ' ', to_char ( quantity ) ), 14, ' ' ) quantity,
			rpad ( decode ( measure, null, ' ', measure ), 1, ' ' ) measure,
			rpad ( decode ( other_descrip, null, ' ', other_descrip ), 30, ' ' ) other_descrip,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_control_sub
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.quantity );
	  utl_file.put ( redaction_pkg.v_file_header, x.measure );
	  utl_file.put ( redaction_pkg.v_file_header, x.other_descrip );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_control_sub;
    procedure write_gs_count is
    -- pre:  data in GS_COUNT is expunged
    -- post:  ASCII file table_gs_count.txt written to OS directory in file format specified by requirements
    begin -- write_gs_count
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_count.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_COUNT';
      for x in ( select rpad ( decode ( c.district, null, ' ', c.district ), 10, ' ' ) district,
                        rpad ( decode ( c.caseid, null, ' ', c.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( instid ), null, ' ', to_char ( instid ) ), 10, ' ' ) instid,
                        rpad ( decode ( charge, null, ' ', decode ( rcl1.process_name, null, charge,
                                                                                       redaction_pkg.c_mask ) ), 25, ' ' ) charge,
                        rpad ( decode ( category, null, ' ', decode ( rcl1.process_name, null, category,
                                                                                         redaction_pkg.c_mask ) ), 1, ' ' ) category,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user,
                        rpad ( decode ( pent_prov, null, ' ',
                                                   decode ( rcl1.process_name, null, pent_prov,
                                                                               redaction_pkg.c_mask ) ), 25, ' ' ) pent_prov
                   from gs_count c,
                        nl_redacted_cases_log rcl1
                  where c.district = rcl1.district(+) and
                        c.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by c.district, c.caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.instid );
          utl_file.put ( redaction_pkg.v_file_header, x.charge );
          utl_file.put ( redaction_pkg.v_file_header, x.category );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          utl_file.put ( redaction_pkg.v_file_header, x.pent_prov );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_count;
    procedure write_gs_court_hist is
    -- pre:  data in GS_COURT_HIST is expunged
    -- post:  ASCII file table_gs_court_hist.txt written to OS directory in file format specified by requirements
    begin -- write_gs_court_hist
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_court_hist.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_COURT_HIST';
      for x in ( select rpad ( decode ( ch.district, null, ' ', ch.district ), 10, ' ' ) district,
                        rpad ( decode ( ch.caseid, null, ' ', ch.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( court, null, ' ', court ), 2, ' ' ) court,
                        rpad ( decode ( location, null, ' ', location ), 2, ' ' ) location,
                        rpad ( decode ( us_role, null, ' ', us_role ), 2, ' ' ) us_role,
                        rpad ( decode ( court_number, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) court_number,
                        rpad ( decode ( filing_date, null, ' ', decode ( rcl1.process_name, null, to_char ( filing_date, 'DD-MON-YYYY' ),
                                                                                            redaction_pkg.c_mask ) ), 11, ' ' ) filing_date,
                        rpad ( decode ( service_date, null, ' ', to_char ( service_date, 'DD-MON-YYYY' ) ), 11, ' ' ) service_date,
                        rpad ( decode ( to_char ( trial_days ), null, ' ', to_char ( trial_days ) ), 14, ' ' ) trial_days,
                        rpad ( decode ( noap_date, null, ' ', to_char ( noap_date, 'DD-MON-YYYY' ) ), 11, ' ' ) noap_date,
                        rpad ( decode ( appeal_type, null, ' ', appeal_type ), 1, ' ' ) appeal_type,
                        rpad ( decode ( sent_appeal, null, ' ', sent_appeal ), 1, ' ' ) sent_appeal,
                        rpad ( decode ( disposition, null, ' ', disposition ), 2, ' ' ) disposition,
                        rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
                        rpad ( decode ( disp_reason1, null, ' ', disp_reason1 ), 4, ' ' ) disp_reason1,
                        rpad ( decode ( disp_reason2, null, ' ', disp_reason2 ), 4, ' ' ) disp_reason2,
                        rpad ( decode ( disp_reason3, null, ' ', disp_reason3 ), 4, ' ' ) disp_reason3,
                        rpad ( decode ( sys_disp_date, null, ' ', to_char ( sys_disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sys_disp_date,
                        rpad ( decode ( sys_filing_date, null, ' ', decode ( rcl1.process_name, null, to_char ( sys_filing_date, 'DD-MON-YYYY' ),
                                                                                                redaction_pkg.c_mask ) ), 11, ' ' ) sys_filing_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_court_hist ch,
                        nl_redacted_cases_log rcl1
                  where ch.district = rcl1.district(+) and
                        ch.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by ch.district, ch.caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.court );
          utl_file.put ( redaction_pkg.v_file_header, x.location );
          utl_file.put ( redaction_pkg.v_file_header, x.us_role );
          utl_file.put ( redaction_pkg.v_file_header, x.court_number );
          utl_file.put ( redaction_pkg.v_file_header, x.filing_date );
          utl_file.put ( redaction_pkg.v_file_header, x.service_date );
          utl_file.put ( redaction_pkg.v_file_header, x.trial_days );
          utl_file.put ( redaction_pkg.v_file_header, x.noap_date );
          utl_file.put ( redaction_pkg.v_file_header, x.appeal_type );
          utl_file.put ( redaction_pkg.v_file_header, x.sent_appeal );
          utl_file.put ( redaction_pkg.v_file_header, x.disposition );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason1 );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason2 );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason3 );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_disp_date );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_filing_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_court_hist;
    procedure write_gs_court_judge is
    -- pre:  data in GS_COURT_JUDGE is expunged
    -- post:  ASCII file table_gs_court_judge.txt written to OS directory in file format specified by requirements
    begin -- write_gs_court_judge
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_court_judge.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_COURT_JUDGE';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( to_char ( judgeid ), null, ' ', to_char ( judgeid ) ), 10, ' ' ) judgeid,
			rpad ( decode ( decision, null, ' ', decision ), 4, ' ' ) decision,
			rpad ( decode ( start_date, null, ' ', to_char ( start_date, 'DD-MON-YYYY' ) ), 11, ' ' ) start_date,
			rpad ( decode ( end_date, null, ' ', to_char ( end_date, 'DD-MON-YYYY' ) ), 11, ' ' ) end_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_court_judge
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.judgeid );
	  utl_file.put ( redaction_pkg.v_file_header, x.decision );
	  utl_file.put ( redaction_pkg.v_file_header, x.start_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.end_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_court_judge;
    procedure write_gs_defend_stat is
    -- pre:  data in GS_DEFEND_STAT is expunged
    -- post:  ASCII file table_gs_defend_stat.txt written to OS directory in file format specified by requirements
    begin -- write_gs_defend_stat
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_defend_stat.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_DEFEND_STAT';
      for x in ( select rpad ( decode ( ds.caseid, null, ' ', ds.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( ds.district, null, ' ', ds.district ), 10, ' ' ) district,
                        rpad ( decode ( type, null, ' ', decode ( rcl1.process_name, null, type,
                                                                                     redaction_pkg.c_mask ) ), 2, ' ' ) type,
                        rpad ( decode ( start_date, null, ' ', to_char ( start_date, 'DD-MON-YYYY' ) ), 11, ' ' ) start_date,
                        rpad ( decode ( custody_loc, null, ' ', custody_loc ), 2, ' ' ) custody_loc,
                        rpad ( decode ( deten_reason, null, ' ', deten_reason ), 4, ' ' ) deten_reason,
                        rpad ( decode ( bond_type, null, ' ', bond_type ), 2, ' ' ) bond_type,
                        rpad ( decode ( to_char ( bond_amount ), null, ' ', to_char ( bond_amount ) ), 14, ' ' ) bond_amount,
                        rpad ( decode ( bond_provider, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) bond_provider,
                        rpad ( decode ( term_reason, null, ' ', term_reason ), 2, ' ' ) term_reason,
                        rpad ( decode ( end_date, null, ' ', to_char ( end_date, 'DD-MON-YYYY' ) ), 11, ' ' ) end_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_defend_stat ds,
                        nl_redacted_cases_log rcl1
                  where ds.district = rcl1.district(+) and
                        ds.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by ds.district, ds.caseid ) loop
        begin
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.type );
          utl_file.put ( redaction_pkg.v_file_header, x.start_date );
          utl_file.put ( redaction_pkg.v_file_header, x.custody_loc );
          utl_file.put ( redaction_pkg.v_file_header, x.deten_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.bond_type );
          utl_file.put ( redaction_pkg.v_file_header, x.bond_amount );
          utl_file.put ( redaction_pkg.v_file_header, x.bond_provider );
          utl_file.put ( redaction_pkg.v_file_header, x.term_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.end_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_defend_stat;
    procedure write_gs_event is
    -- pre:  data in GS_EVENT is expunged
    -- post:  ASCII file table_gs_event.txt written to OS directory in file format specified by requirements
      l_district  varchar2 ( 10 ) := 'NONE';
    begin -- write_gs_event
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_EVENT';
      for x in ( select rpad ( decode ( e.district, null, ' ', e.district ), 10, ' ' ) district,
                        rpad ( decode ( e.caseid, null, ' ', e.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( type, null, ' ',
                                              decode ( rcl1.process_name || rcl2.process_name, null, type,
                                                                                               redaction_pkg.c_mask ) ), 4, ' ' ) type,
                        rpad ( decode ( action, null, ' ',
                                                decode ( rcl1.process_name || rcl2.process_name, null, action,
                                                                                                 redaction_pkg.c_mask ) ), 2, ' ' ) action,
                        rpad ( decode ( event_date, null, ' ',
                                                    decode ( rcl1.process_name || rcl2.process_name, null, to_char ( event_date, 'DD-MON-YYYY' ),
                                                                                                     redaction_pkg.c_mask ) ), 11, ' ' ) event_date,
                        rpad ( decode ( sched_date, null, ' ',
                                                    decode ( rcl1.process_name || rcl2.process_name, null, to_char ( sched_date, 'DD-MON-YYYY' ),
                                                                                                     redaction_pkg.c_mask ) ), 11, ' ' ) sched_date,
                        -- rpad ( decode ( sched_time, null, ' ', to_char ( sched_time, 'DD-MON-YYYY' ) ), 11, ' ' ) sched_time,
			rpad ( decode ( sched_time, null, ' ', to_char ( sched_time, 'HH:MI AM' ) ), 11, ' ' ) sched_time,
                        rpad ( decode ( sched_loc, null, ' ', redaction_pkg.c_mask ), 200, ' ' ) sched_loc,
                        rpad ( decode ( to_char ( staffid ), null, ' ', to_char ( staffid ) ), 10, ' ' ) staffid,
                        rpad ( decode ( to_char ( judgeid ), null, ' ', to_char ( judgeid ) ), 10, ' ' ) judgeid,
                        rpad ( decode ( document_code, null, ' ',
                                                       decode ( rcl1.process_name || rcl2.process_name, null, document_code,
                                                                                                        redaction_pkg.c_mask ) ), 3, ' ' ) document_code,
                        rpad ( decode ( to_char ( document_staffid ), null, ' ', to_char ( document_staffid ) ), 10, ' ' ) document_staffid,
                        rpad ( decode ( document_date, null, ' ',
                                                       decode ( rcl1.process_name || rcl2.process_name, null, to_char ( document_date, 'DD-MON-YYYY' ),
                                                                                                        redaction_pkg.c_mask ) ), 11, ' ' ) document_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_event e,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where e.district = rcl1.district(+) and
                        e.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        e.district = rcl2.district(+) and
                        e.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by e.district, e.caseid
               ) loop
        begin -- exception handling block
          -- store district we are working on in l_district
          -- if x.district is different, we are working on a new district b/c we sort by district
          -- close the file if it's open and log the record count for the prior district
          if x.district <> l_district then
            if utl_file.is_open ( redaction_pkg.v_file_header ) then
              redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
              utl_file.fclose ( redaction_pkg.v_file_header );
              redaction_pkg.v_count := 0;
            end if;
            l_district := x.district;
            redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                                            'gs_event_' || rtrim ( l_district, ' ' ) || '.txt',
                                                            'w',
                                                            redaction_pkg.c_linesize );
          end if;
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.type );
          utl_file.put ( redaction_pkg.v_file_header, x.action );
          utl_file.put ( redaction_pkg.v_file_header, x.event_date );
          utl_file.put ( redaction_pkg.v_file_header, x.sched_date );
          utl_file.put ( redaction_pkg.v_file_header, x.sched_time );
          utl_file.put ( redaction_pkg.v_file_header, x.sched_loc );
          utl_file.put ( redaction_pkg.v_file_header, x.staffid );
          utl_file.put ( redaction_pkg.v_file_header, x.judgeid );
          utl_file.put ( redaction_pkg.v_file_header, x.document_code );
          utl_file.put ( redaction_pkg.v_file_header, x.document_staffid );
          utl_file.put ( redaction_pkg.v_file_header, x.document_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      -- close last district
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
      utl_file.fclose ( redaction_pkg.v_file_header );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_event;
    procedure write_gs_evidence is
    -- pre:  data in GS_EVIDENCE is expunged
    -- post:  ASCII file table_gs_evidence.txt written to OS directory in file format specified by requirements
    begin -- write_gs_evidence
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_evidence.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_EVIDENCE';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
		        rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( location, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) location,
                        rpad ( decode ( type, null, ' ', redaction_pkg.c_mask ), 2, ' ' ) type,
                        rpad ( decode ( disposition, null, ' ', disposition ), 1, ' ' ) disposition,
                        rpad ( decode ( store_date, null, ' ', to_char ( store_date, 'DD-MON-YYYY' ) ), 11, ' ' ) store_date,
                        rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
                        rpad ( decode ( dc_exhibit_num, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) dc_exhibit_num,
                        rpad ( decode ( gj_exhibit_num, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) gj_exhibit_num,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_evidence
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.location );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.disposition );
	  utl_file.put ( redaction_pkg.v_file_header, x.store_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.dc_exhibit_num );
	  utl_file.put ( redaction_pkg.v_file_header, x.gj_exhibit_num );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_evidence;
    procedure write_gs_expert_case is
    -- pre:  data in GS_EXPERT_CASE is expunged
    -- post:  ASCII file table_gs_expert_case.txt written to OS directory in file format specified by requirements
    begin -- write_gs_expert_case
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_expert_case.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_EXPERT_CASE';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( exp_side, null, ' ', exp_side ), 1, ' ' ) exp_side,
			rpad ( decode ( to_char ( expertid ), null, ' ', to_char ( expertid ) ), 10, ' ' ) expertid,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_expert_case
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.exp_side );
	  utl_file.put ( redaction_pkg.v_file_header, x.expertid );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_expert_case;
    procedure write_gs_instrument is
    -- pre:  data in GS_INSTRUMENT is expunged
    -- post:  ASCII file table_gs_instrument.txt written to OS directory in file format specified by requirements
    begin -- write_gs_instrument
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_instrument.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_INSTRUMENT';
      for x in ( select rpad ( decode ( i.district, null, ' ', i.district ), 10, ' ' ) district,
                        rpad ( decode ( i.caseid, null, ' ', i.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( type, null, ' ',
                                              decode ( rcl1.process_name, null, type,
                                                                          redaction_pkg.c_mask ) ), 2, ' ' ) type,
                        rpad ( decode ( filing_date, null, ' ',
                                                     decode ( rcl1.process_name, null, to_char ( filing_date, 'DD-MON-YYYY' ),
                                                                                 redaction_pkg.c_mask ) ), 11, ' ' ) filing_date,
                        rpad ( decode ( sys_filing_date, null, ' ',
                                                         decode ( rcl1.process_name, null, to_char ( sys_filing_date, 'DD-MON-YYYY' ),
                                                                                     redaction_pkg.c_mask ) ), 11, ' ' ) sys_filing_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_instrument i,
                        nl_redacted_cases_log rcl1
                  where i.district = rcl1.district(+) and
                        i.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by i.district, i.caseid ) loop
        begin  -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.type );
          utl_file.put ( redaction_pkg.v_file_header, x.filing_date );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_filing_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_instrument;
    procedure write_gs_inst_charge is
    -- pre:  data in GS_INST_CHARGE is expunged
    -- post:  ASCII file table_gs_inst_charge.txt written to OS directory in file format specified by requirements
    begin -- write_gs_inst_charge
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_inst_charge.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_INST_CHARGE';
      for x in ( select rpad ( decode ( ic.district, null, ' ', ic.district ), 10, ' ' ) district,
                        rpad ( decode ( ic.caseid, null, ' ', ic.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( instid ), null, ' ', to_char ( instid ) ), 10, ' ' ) instid,
                        rpad ( decode ( charge, null, ' ',
                                                decode ( rcl1.process_name, null, charge,
                                                                            redaction_pkg.c_mask ) ), 25, ' ' ) charge,
                        rpad ( decode ( category, null, ' ',
                                                  decode ( rcl1.process_name, null, category,
                                                                              redaction_pkg.c_mask ) ), 1, ' ' ) category,
                        rpad ( decode ( pent_prov, null, ' ',
                                                   decode ( rcl1.process_name, null, pent_prov,
                                                                               redaction_pkg.c_mask ) ), 25, ' ' ) pent_prov,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user,
                        rpad ( decode ( id, null, ' ', id ), 10, ' ' ) id
                   from gs_inst_charge ic,
                        nl_redacted_cases_log rcl1
                  where ic.district = rcl1.district(+) and
                        ic.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by ic.district, ic.caseid ) loop
        begin  -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.instid );
          utl_file.put ( redaction_pkg.v_file_header, x.charge );
          utl_file.put ( redaction_pkg.v_file_header, x.category );
          utl_file.put ( redaction_pkg.v_file_header, x.pent_prov );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_inst_charge;
    procedure write_gs_oppose_coun is
    -- pre:  data in GS_OPPOSE_COUN is expunged
    -- post:  ASCII file table_gs_oppose_coun.txt written to OS directory in file format specified by requirements
    begin -- write_gs_oppose_coun
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_oppose_coun.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_OPPOSE_COUN';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( to_char ( attorneyid ), null, ' ', to_char ( attorneyid ) ), 10, ' ' ) attorneyid,
			rpad ( decode ( type, null, ' ', type ), 2, ' ' ) type,
			rpad ( decode ( start_date, null, ' ', to_char ( start_date, 'DD-MON-YYYY' ) ), 11, ' ' ) start_date,
			rpad ( decode ( end_date, null, ' ', to_char ( end_date, 'DD-MON-YYYY' ) ), 11, ' ' ) end_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_oppose_coun
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.attorneyid );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.start_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.end_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_oppose_coun;
    procedure write_gs_part_count is
    -- pre:  data in GS_PART_COUnT is expunged
    -- post:  ASCII file table_gs_part_count.txt written to OS directory in file format specified by requirements
    begin -- write_gs_part_count
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_part_count.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PART_COUNT';
      for x in ( select rpad ( decode ( pcn.district, null, ' ', pcn.district ), 10, ' ' ) district,
                        rpad ( decode ( pcn.caseid, null, ' ', pcn.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
                        rpad ( decode ( to_char ( instid ), null, ' ', to_char ( instid ) ), 10, ' ' ) instid,
                        rpad ( decode ( charge, null, ' ',
                                                decode ( rcl1.process_name, null, charge,
                                                                            redaction_pkg.c_mask ) ), 25, ' ' ) charge,
                        rpad ( decode ( category, null, ' ',
                                                  decode ( rcl1.process_name, null, category,
                                                                              redaction_pkg.c_mask ) ), 1, ' ' ) category,
                        rpad ( decode ( to_char ( countid ), null, ' ', to_char ( countid ) ), 10, ' ' ) countid,
                        rpad ( decode ( disposition, null, ' ', disposition ), 2, ' ' ) disposition,
                        rpad ( decode ( disp_reason, null, ' ', disp_reason ), 4, ' ' ) disp_reason,
                        rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
			rpad ( decode ( sealed, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) sealed,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_part_count pcn,
                        nl_redacted_cases_log rcl1
                  where pcn.district = rcl1.district(+) and
                        pcn.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED'
                 order by pcn.district, pcn.caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
          utl_file.put ( redaction_pkg.v_file_header, x.instid );
          utl_file.put ( redaction_pkg.v_file_header, x.charge );
          utl_file.put ( redaction_pkg.v_file_header, x.category );
          utl_file.put ( redaction_pkg.v_file_header, x.countid );
          utl_file.put ( redaction_pkg.v_file_header, x.disposition );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
          utl_file.put ( redaction_pkg.v_file_header, x.sealed );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_part_count;
    procedure write_gs_part_court is
    -- pre:  data in GS_PART_COURT is expunged
    -- post:  ASCII file table_gs_part_court.txt written to OS directory in file format specified by requirements
    begin -- write_gs_part_court
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_part_court.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PART_COURT';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
			rpad ( decode ( appeal_role, null, ' ', appeal_role ), 2, ' ' ) appeal_role,
			rpad ( decode ( disposition, null, ' ', disposition ), 2, ' ' ) disposition,
			rpad ( decode ( disp_reason, null, ' ', disp_reason ), 4, ' ' ) disp_reason,
			rpad ( decode ( disp_date, null, ' ', to_char ( disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) disp_date,
			rpad ( decode ( sys_disp_date, null, ' ', to_char ( sys_disp_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sys_disp_date,
			rpad ( decode ( sys_init_date, null, ' ', to_char ( sys_init_date, 'DD-MON-YYYY' ) ), 11, ' ' )	sys_init_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_part_court
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
	  utl_file.put ( redaction_pkg.v_file_header, x.appeal_role );
	  utl_file.put ( redaction_pkg.v_file_header, x.disposition );
	  utl_file.put ( redaction_pkg.v_file_header, x.disp_reason );
	  utl_file.put ( redaction_pkg.v_file_header, x.disp_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.sys_disp_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.sys_init_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_part_court;
   procedure write_gs_part_event is
    -- pre:  data in GS_PART_EVENT is expunged
    -- post:  ASCII file table_gs_part_event.txt written to OS directory in file format specified by requirements
       l_district  varchar2 ( 10 ) := 'NONE';
    begin -- write_gs_part_event
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PART_EVENT';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
			rpad ( decode ( to_char ( eventid ), null, ' ', to_char ( eventid ) ), 10, ' ' ) eventid,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_part_event
                  order by district, caseid
               ) loop

        begin
          -- store district we are working on in l_district
          -- if x.district is different, we are working on a new district b/c we sort by district
          -- close the file if it's open and log the record count for the prior district
          if x.district <> l_district then
            if utl_file.is_open ( redaction_pkg.v_file_header ) then
              redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
              utl_file.fclose ( redaction_pkg.v_file_header );
              redaction_pkg.v_count := 0;
            end if;
            l_district := x.district;
            redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                                            'gs_part_event_' || rtrim ( l_district, ' ' ) || '.txt',
                                                            'w',
                                                            redaction_pkg.c_linesize );
          end if;
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
	  utl_file.put ( redaction_pkg.v_file_header, x.eventid );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      -- close last district
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
      utl_file.fclose ( redaction_pkg.v_file_header );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_part_event;
    procedure write_gs_part_relief is
    -- pre:  data in GS_PART_RELIEF is expunged
    -- post:  ASCII file table_gs_part_relief.txt written to OS directory in file format specified by requirements
    begin -- write_gs_part_relief
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_part_relief.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PART_RELIEF';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( reliefid ), null, ' ', to_char ( reliefid ) ), 10, ' ' ) reliefid,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_part_relief
                  order by district, caseid
               ) loop
        begin
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.reliefid );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_part_relief;
    procedure write_gs_part_victim is
    -- pre:  data in GS_PART_VICTIM is expunged
    -- post:  ASCII file table_gs_part_victim.txt written to OS directory in file format specified by requirements
    begin -- write_gs_part_victim
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_part_victim.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PART_VICTIM';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
 			rpad ( decode ( to_char ( partid ), null, ' ', redaction_pkg.c_mask ), 10, ' ' ) partid,
 			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
 			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
 			rpad ( decode ( victim_type, null, ' ', victim_type ), 1, ' ' ) victim_type,
 			rpad ( decode ( prosecution, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) prosecution,
 			rpad ( decode ( to_char ( victim_times ), null, ' ', redaction_pkg.c_mask ), 11, ' ' ) victim_times,
 			rpad ( decode ( threats, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) threats,
 			rpad ( decode ( elderly, null, ' ', elderly ), 1, ' ' ) elderly,
 			rpad ( decode ( victim_identifier, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) victim_identifier,
 			rpad ( decode ( to_char ( state_comp_recvd ), null, ' ', redaction_pkg.c_mask ), 14, ' ' ) state_comp_recvd,
 			rpad ( decode ( services_requested, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) services_requested,
 			rpad ( decode ( violent_crime, null, ' ', violent_crime ), 1, ' ' ) violent_crime,
 			rpad ( decode ( disability, null, ' ', disability ), 1, ' ' ) disability,
 			rpad ( decode ( notificat_reqstd, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) notificat_reqstd,
 			rpad ( decode ( notificat_recvd, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) notificat_recvd,
                        partid partid_err,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_part_victim
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid_err;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.victim_type );
	  utl_file.put ( redaction_pkg.v_file_header, x.prosecution );
	  utl_file.put ( redaction_pkg.v_file_header, x.victim_times );
	  utl_file.put ( redaction_pkg.v_file_header, x.threats );
	  utl_file.put ( redaction_pkg.v_file_header, x.elderly );
	  utl_file.put ( redaction_pkg.v_file_header, x.victim_identifier );
	  utl_file.put ( redaction_pkg.v_file_header, x.state_comp_recvd );
	  utl_file.put ( redaction_pkg.v_file_header, x.services_requested );
	  utl_file.put ( redaction_pkg.v_file_header, x.violent_crime );
	  utl_file.put ( redaction_pkg.v_file_header, x.disability );
	  utl_file.put ( redaction_pkg.v_file_header, x.notificat_reqstd );
	  utl_file.put ( redaction_pkg.v_file_header, x.notificat_recvd );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_part_victim;
    procedure write_gs_participant is
    -- pre:  data in GS_PARTICIPANT is expunged
    -- post:  ASCII file table_gs_participant.txt written to OS directory in file format specified by requirements
      l_district  varchar2 ( 10 ) := 'NONE';
    begin -- write_gs_participant
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PARTICIPANT';
      for x in ( select rpad ( decode ( p.district, null, ' ', p.district ), 10, ' ' ) district,
                        rpad ( decode ( p.caseid, null, ' ', p.caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
                        rpad ( decode ( type, null, ' ', type ), 1, ' ' ) type,
                        rpad ( decode ( role, null, ' ', decode ( rcl1.process_name || rcl2.process_name, null, role,
                                                                                                          decode ( substr ( role, 1, 1 ),
                                                                                                                   'D', 'D*', redaction_pkg.c_mask ) ) ), 2, ' ' ) role,
                        rpad ( decode ( security, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) security,
                        rpad ( decode ( to_char ( defend_num ), null, ' ', to_char ( defend_num ) ), 11, ' ' ) defend_num,
                        rpad ( decode ( salutation, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) salutation,
                        rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 60, ' ' ) last_name,
                        rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
                        rpad ( decode ( title, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) title,
                        rpad ( decode ( last_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) last_sounds,
                        rpad ( decode ( first_sounds, null, ' ', redaction_pkg.c_mask ), 4, ' ' ) first_sounds,
                        rpad ( decode ( business_type, null, ' ', business_type ), 2, ' ' ) business_type,
                        rpad ( decode ( ein, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) ein,
                        rpad ( decode ( prop_type, null, ' ', prop_type ), 2, ' ' ) prop_type,
                        rpad ( decode ( to_char ( total_tracts ), null, ' ', to_char ( total_tracts ) ), 11, ' ' ) total_tracts,
                        rpad ( decode ( cats_asset_id, null, ' ', cats_asset_id ), 15, ' ' ) cats_asset_id,
                        rpad ( decode ( agency, null, ' ', agency ), 4, ' ' ) agency,
                        rpad ( decode ( agency_num, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) agency_num,
                        rpad ( decode ( job_position, null, ' ', job_position ), 4, ' ' ) job_position,
                        rpad ( decode ( ssn, null, ' ', redaction_pkg.c_mask ), 11, ' ' ) ssn,
                        rpad ( decode ( birth_date, null, ' ', redaction_pkg.c_mask ), 11, ' ' ) birth_date,
                        rpad ( decode ( gender, null, ' ', gender ), 1, ' ' ) gender,
                        rpad ( decode ( juvenile, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) juvenile,
                        rpad ( decode ( race, null, ' ', race ), 2, ' ' ) race,
                        rpad ( decode ( race_descrip, null, ' ', race_descrip ), 30, ' ' ) race_descrip,
                        rpad ( decode ( immig_stat, null, ' ', redaction_pkg.c_mask ), 2, ' ' ) immig_stat,
                        rpad ( decode ( country, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                        country ) ), 2, ' ' ) country,
                        rpad ( decode ( tribe, null, ' ', tribe ), 4, ' ' ) tribe,
                        rpad ( decode ( reservation, null, ' ', reservation ), 4, ' ' ) reservation,
                        rpad ( decode ( arrest_date, null, ' ', redaction_pkg.c_mask ), 11, ' ' ) arrest_date,
                        rpad ( decode ( pdid, null, ' ', redaction_pkg.c_mask ), 12, ' ' ) pdid,
                        rpad ( decode ( fbi_number, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) fbi_number,
                        rpad ( decode ( crim_hist, null, ' ', crim_hist ), 1, ' ' ) crim_hist,
                        rpad ( decode ( to_char ( est_loss ), null, ' ', to_char ( est_loss ) ), 14, ' ' ) est_loss,
                        rpad ( decode ( to_char ( act_loss ), null, ' ', to_char ( act_loss ) ), 14, ' ' ) act_loss,
                        rpad ( decode ( home_address1, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) home_address1,
                        rpad ( decode ( home_address2, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) home_address2,
                        rpad ( decode ( home_address3, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) home_address3,
                        rpad ( decode ( home_city, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                          home_city ) ), 20, ' ' ) home_city,
                        rpad ( decode ( home_state, null, ' ', home_state ), 2, ' ' ) home_state,
                        rpad ( decode ( home_county, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                            home_county ) ), 20, ' ' ) home_county,
                        rpad ( decode ( home_zipcode, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                             home_zipcode ) ), 10, ' ' ) home_zipcode,
                        rpad ( decode ( home_phone, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) home_phone,
                        rpad ( decode ( home_fax, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) home_fax,
                        rpad ( decode ( off_address1, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) off_address1,
                        rpad ( decode ( off_address2, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) off_address2,
                        rpad ( decode ( off_address3, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) off_address3,
                        rpad ( decode ( off_city, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                         off_city ) ), 20, ' ' ) off_city,
                        rpad ( decode ( off_state, null, ' ', off_state ), 2, ' ' ) off_state,
                        rpad ( decode ( off_county, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                           off_county ) ), 20, ' ' ) off_county,
                        rpad ( decode ( off_zipcode, null, ' ', decode ( rpl1.process_name, null, redaction_pkg.c_mask,
                                                                                            off_zipcode ) ), 10, ' ' ) off_zipcode,
                        rpad ( decode ( off_phone, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) off_phone,
                        rpad ( decode ( off_fax, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) off_fax,
                        rpad ( decode ( marshals_num, null, ' ', redaction_pkg.c_mask ), 9, ' ' ) marshals_num,
                        rpad ( decode ( to_char ( agcyoffid ), null, ' ', to_char ( agcyoffid ) ), 10, ' ' ) agcyoffid,
                        rpad ( decode ( lower_crt_trial_nbr, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) lower_crt_trial_nbr,
                        rpad ( decode ( business_contact_lname, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) business_contact_lname,
                        rpad ( decode ( business_contact_fname, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) business_contact_fname,
                        rpad ( decode ( collect_ind, null, ' ', collect_ind ), 1, ' ' ) collect_ind,
                        rpad ( decode ( sys_init_date, null, ' ', to_char ( sys_init_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sys_init_date,
                        rpad ( decode ( weight, null, ' ', weight ), 2, ' ' ) weight,
                        rpad ( decode ( employer_name, null, ' ', redaction_pkg.c_mask ), 40, ' ' ) employer_name,
                        rpad ( decode ( employer_type, null, ' ', employer_type ), 3, ' ' ) employer_type,
                        rpad ( decode ( employer_desc, null, ' ', employer_desc ), 40, ' ' ) employer_desc,
                        rpad ( decode ( npi, null, ' ', redaction_pkg.c_mask ), 10, ' ' ) npi,
                        rpad ( decode ( occupation, null, ' ', occupation ), 3, ' ' ) occupation,
                        rpad ( decode ( occup_desc, null, ' ', occup_desc ), 60, ' ' ) occup_desc,
                        rpad ( decode ( hcare_busn_type, null, ' ', hcare_busn_type ), 3, ' ' ) hcare_busn_type,
                        rpad ( decode ( hcare_busn_desc, null, ' ', hcare_busn_desc ), 40, ' ' ) hcare_busn_desc,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_participant p,
                        nl_redacted_participants_log rpl1,
                        nl_redacted_cases_log rcl1,
                        nl_redacted_cases_log rcl2
                  where p.district = rpl1.district(+) and
                        p.caseid = rpl1.caseid(+) and
                        p.id = rpl1.partid(+) and
                        p.district = rcl1.district(+) and
                        p.caseid = rcl1.caseid(+) and
                        rcl1.process_name(+) = 'SEALED' and
                        p.district = rcl2.district(+) and
                        p.caseid = rcl2.caseid(+) and
                        rcl2.process_name(+) = 'ONGOING'
                 order by p.district, p.caseid, p.id
                  ) loop
        begin -- exception handling block
          -- store district we are working on in l_district
          -- if x.district is different, we are working on a new district b/c we sort by district
          -- close the file if it's open and log the record count for the prior district
          if x.district <> l_district then
            if utl_file.is_open ( redaction_pkg.v_file_header ) then
              redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
              utl_file.fclose ( redaction_pkg.v_file_header );
              redaction_pkg.v_count := 0;
            end if;
            l_district := x.district;
            redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                                            'gs_participant_' || rtrim ( l_district, ' ' ) || '.txt',
                                                            'w',
                                                            redaction_pkg.c_linesize );
          end if;
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.id;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          utl_file.put ( redaction_pkg.v_file_header, x.type );
          utl_file.put ( redaction_pkg.v_file_header, x.role );
          utl_file.put ( redaction_pkg.v_file_header, x.security );
          utl_file.put ( redaction_pkg.v_file_header, x.defend_num );
          utl_file.put ( redaction_pkg.v_file_header, x.salutation );
          utl_file.put ( redaction_pkg.v_file_header, x.last_name );
          utl_file.put ( redaction_pkg.v_file_header, x.first_name );
          utl_file.put ( redaction_pkg.v_file_header, x.title );
          utl_file.put ( redaction_pkg.v_file_header, x.last_sounds );
          utl_file.put ( redaction_pkg.v_file_header, x.first_sounds );
          utl_file.put ( redaction_pkg.v_file_header, x.business_type );
          utl_file.put ( redaction_pkg.v_file_header, x.ein );
          utl_file.put ( redaction_pkg.v_file_header, x.prop_type );
          utl_file.put ( redaction_pkg.v_file_header, x.total_tracts );
          utl_file.put ( redaction_pkg.v_file_header, x.cats_asset_id );
          utl_file.put ( redaction_pkg.v_file_header, x.agency );
          utl_file.put ( redaction_pkg.v_file_header, x.agency_num );
          utl_file.put ( redaction_pkg.v_file_header, x.job_position );
          utl_file.put ( redaction_pkg.v_file_header, x.ssn );
          utl_file.put ( redaction_pkg.v_file_header, x.birth_date );
          utl_file.put ( redaction_pkg.v_file_header, x.gender );
          utl_file.put ( redaction_pkg.v_file_header, x.juvenile );
          utl_file.put ( redaction_pkg.v_file_header, x.race );
          utl_file.put ( redaction_pkg.v_file_header, x.race_descrip );
          utl_file.put ( redaction_pkg.v_file_header, x.immig_stat );
          utl_file.put ( redaction_pkg.v_file_header, x.country );
          utl_file.put ( redaction_pkg.v_file_header, x.tribe );
          utl_file.put ( redaction_pkg.v_file_header, x.reservation );
          utl_file.put ( redaction_pkg.v_file_header, x.arrest_date );
          utl_file.put ( redaction_pkg.v_file_header, x.pdid );
          utl_file.put ( redaction_pkg.v_file_header, x.fbi_number );
          utl_file.put ( redaction_pkg.v_file_header, x.crim_hist );
          utl_file.put ( redaction_pkg.v_file_header, x.est_loss );
          utl_file.put ( redaction_pkg.v_file_header, x.act_loss );
          utl_file.put ( redaction_pkg.v_file_header, x.home_address1 );
          utl_file.put ( redaction_pkg.v_file_header, x.home_address2 );
          utl_file.put ( redaction_pkg.v_file_header, x.home_address3 );
          utl_file.put ( redaction_pkg.v_file_header, x.home_city );
          utl_file.put ( redaction_pkg.v_file_header, x.home_state );
          utl_file.put ( redaction_pkg.v_file_header, x.home_county );
          utl_file.put ( redaction_pkg.v_file_header, x.home_zipcode );
          utl_file.put ( redaction_pkg.v_file_header, x.home_phone );
          utl_file.put ( redaction_pkg.v_file_header, x.home_fax );
          utl_file.put ( redaction_pkg.v_file_header, x.off_address1 );
          utl_file.put ( redaction_pkg.v_file_header, x.off_address2 );
          utl_file.put ( redaction_pkg.v_file_header, x.off_address3 );
          utl_file.put ( redaction_pkg.v_file_header, x.off_city );
          utl_file.put ( redaction_pkg.v_file_header, x.off_state );
          utl_file.put ( redaction_pkg.v_file_header, x.off_county );
          utl_file.put ( redaction_pkg.v_file_header, x.off_zipcode );
          utl_file.put ( redaction_pkg.v_file_header, x.off_phone );
          utl_file.put ( redaction_pkg.v_file_header, x.off_fax );
          utl_file.put ( redaction_pkg.v_file_header, x.marshals_num );
          utl_file.put ( redaction_pkg.v_file_header, x.agcyoffid );
          utl_file.put ( redaction_pkg.v_file_header, x.lower_crt_trial_nbr );
          utl_file.put ( redaction_pkg.v_file_header, x.business_contact_lname );
          utl_file.put ( redaction_pkg.v_file_header, x.business_contact_fname );
          utl_file.put ( redaction_pkg.v_file_header, x.collect_ind );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_init_date );
          utl_file.put ( redaction_pkg.v_file_header, x.weight );
          utl_file.put ( redaction_pkg.v_file_header, x.employer_name );
          utl_file.put ( redaction_pkg.v_file_header, x.employer_type );
          utl_file.put ( redaction_pkg.v_file_header, x.employer_desc );
          utl_file.put ( redaction_pkg.v_file_header, x.npi );
          utl_file.put ( redaction_pkg.v_file_header, x.occupation );
          utl_file.put ( redaction_pkg.v_file_header, x.occup_desc );
          utl_file.put ( redaction_pkg.v_file_header, x.hcare_busn_type );
          utl_file.put ( redaction_pkg.v_file_header, x.hcare_busn_desc );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      -- close last district
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name || '_' || l_district, redaction_pkg.v_count );
      utl_file.fclose ( redaction_pkg.v_file_header );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_participant;
    procedure write_gs_prop_value is
    -- pre:  data in GS_PROP_VALUE is expunged
    -- post:  ASCII file table_gs_prop_value.txt written to OS directory in file format specified by requirements
    begin -- write_gs_prop_value
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_prop_value.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_PROP_VALUE';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( type, null, ' ', type ), 2, ' ' ) type,
			rpad ( decode ( to_char ( value ), null, ' ', to_char ( value ) ), 14, ' ' ) value,
			rpad ( decode ( prop_date, null, ' ', to_char ( prop_date, 'DD-MON-YYYY' ) ), 11, ' ' ) prop_date,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_prop_value
                  order by district, caseid
               ) loop
        begin
	-- Set the globals for the redaction_pkg.write_error exception.
	redaction_pkg.v_district := substr ( x.district, 1, 3 );
	redaction_pkg.v_caseid := x.caseid;
	redaction_pkg.v_partid := x.partid;
	utl_file.put ( redaction_pkg.v_file_header, x.district );
        utl_file.put ( redaction_pkg.v_file_header, x.caseid );
        utl_file.put ( redaction_pkg.v_file_header, x.partid );
        utl_file.put ( redaction_pkg.v_file_header, x.id );
        utl_file.put ( redaction_pkg.v_file_header, x.type );
        utl_file.put ( redaction_pkg.v_file_header, x.value );
	utl_file.put ( redaction_pkg.v_file_header, x.prop_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
        -- carriage return to the next line
        utl_file.new_line ( redaction_pkg.v_file_header );
	redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_prop_value;
    procedure write_gs_region is
    -- pre:  data in GS_REGION is expunged
    -- post:  ASCII file table_gs_region.txt written to OS directory in file format specified by requirements
    begin -- write_gs_region
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_region.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_REGION';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 3, ' ' ) district,
			rpad ( decode ( branch, null, ' ', branch ), 3, ' ' ) branch,
			rpad ( decode ( description, null, ' ', description ), 30, ' ' ) description,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_region
                  order by district, branch
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.branch );
          utl_file.put ( redaction_pkg.v_file_header, x.description );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_region;
    procedure write_gs_relate_appeal is
    -- pre:  data in GS_RELATE_APPEAL is expunged
    -- post:  ASCII file table_gs_relate_appeal.txt written to OS directory in file format specified by requirements
    begin -- write_gs_relate_appeal
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_relate_appeal.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_count := 0;
      redaction_pkg.v_table_name := 'GS_RELATE_APPEAL';
      for x in ( select rpad ( decode ( caseid1, null, ' ', caseid1 ), 10, ' ' ) caseid1,
			rpad ( decode ( to_char ( crthisid1 ), null, ' ', to_char ( crthisid1 ) ), 10, ' ' ) crthisid1,
			rpad ( decode ( caseid2, null, ' ', caseid2 ), 10, ' ' ) caseid2,
			rpad ( decode ( to_char ( crthisid2 ), null, ' ', to_char ( crthisid2 ) ), 10, ' ' ) crthisid2,
			rpad ( decode ( reason, null, ' ', reason ), 2, ' ' ) reason,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_relate_appeal
                  order by district, caseid1, caseid2
               ) loop
        begin
        -- Set the globals for the redaction_pkg.write_error exception.
        redaction_pkg.v_district := substr ( x.district, 1, 3 );
	redaction_pkg.v_caseid := x.caseid1;
        utl_file.put ( redaction_pkg.v_file_header, x.district );
        utl_file.put ( redaction_pkg.v_file_header, x.caseid1 );
        utl_file.put ( redaction_pkg.v_file_header, x.crthisid1 );
        utl_file.put ( redaction_pkg.v_file_header, x.caseid2 );
        utl_file.put ( redaction_pkg.v_file_header, x.crthisid2 );
        utl_file.put ( redaction_pkg.v_file_header, x.reason );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
        -- carriage return to the next line
        utl_file.new_line ( redaction_pkg.v_file_header );
	redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_relate_appeal;
    procedure write_gs_relate_case is
    -- pre:  data in GS_RELATE_CASE is expunged
    -- post:  ASCII file table_gs_relate_case.txt written to OS directory in file format specified by requirements
    begin -- write_gs_relate_case
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_relate_case.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_count := 0;
      redaction_pkg.v_table_name := 'GS_RELATE_CASE';
      for x in ( select rpad ( decode ( caseid1, null, ' ', caseid1 ), 10, ' ' ) caseid1,
			rpad ( decode ( caseid2, null, ' ', caseid2 ), 10, ' ' ) caseid2,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( to_char ( crthisid1 ), null, ' ', to_char ( crthisid1 ) ), 10, ' ' ) crthisid1,
			rpad ( decode ( to_char ( crthisid2 ), null, ' ', to_char ( crthisid2 ) ), 10, ' ' ) crthisid2,
			rpad ( decode ( reason, null, ' ', reason ), 2, ' ' ) reason,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user,
                        rpad ( decode ( id, null, ' ', id ), 10, ' ' ) id
                   from gs_relate_case
                  order by district, caseid1, caseid2
               ) loop
        begin
	  -- Set the globals for the redaction_pkg.write_error exception.
	  redaction_pkg.v_district := substr ( x.district, 1, 3 );
	  redaction_pkg.v_caseid := x.caseid1;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid1 );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid2 );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid1 );
          utl_file.put ( redaction_pkg.v_file_header, x.crthisid2 );
          utl_file.put ( redaction_pkg.v_file_header, x.reason );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
	  redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    end write_gs_relate_case;
    procedure write_gs_relate_part is
    -- pre:  data in gs_relate_part is expunged
    -- post:  ASCII file table_gs_relate_part.txt written to OS directory in file format specified by requirements
    begin -- write_gs_relate_part
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_relate_part.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_RELATE_PART';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid1 ), null, ' ', to_char ( partid1 ) ), 10, ' ' ) partid1,
			rpad ( decode ( to_char ( partid2 ), null, ' ', to_char ( partid2 ) ), 10, ' ' ) partid2,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( reason, null, ' ', reason ), 2, ' ' ) reason,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_relate_part
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid1;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid1 );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid2 );
	  utl_file.put ( redaction_pkg.v_file_header, x.reason );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_relate_part;
    procedure write_gs_relief is
    -- pre:  data in GS_RELIEF is expunged
    -- post:  ASCII file table_gs_relief.txt written to OS directory in file format specified by requirements
    begin -- write_gs_relief
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_relief.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_RELIEF';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( type, null, ' ', type ), 1, ' ' ) type,
			rpad ( decode ( stage, null, ' ', stage ), 1, ' ' ) stage,
			rpad ( decode ( requested_by, null, ' ', requested_by ), 1, ' ' ) requested_by,
			rpad ( decode ( liability, null, ' ', liability ), 1, ' ' ) liability,
			rpad ( decode ( to_char ( amount ), null, ' ', to_char ( amount ) ), 16, ' ' ) amount,
			rpad ( decode ( nonmonetary, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) nonmonetary,
			rpad ( decode ( agency, null, ' ', agency ), 4, ' ' ) agency,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_relief
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.stage );
	  utl_file.put ( redaction_pkg.v_file_header, x.requested_by );
	  utl_file.put ( redaction_pkg.v_file_header, x.liability );
	  utl_file.put ( redaction_pkg.v_file_header, x.amount );
	  utl_file.put ( redaction_pkg.v_file_header, x.nonmonetary );
	  utl_file.put ( redaction_pkg.v_file_header, x.agency );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_relief;
    procedure write_gs_request is
    -- pre:  data in GS_REQUEST is expunged
    -- post:  ASCII file table_gs_request.txt written to OS directory in file format specified by requirements
    begin -- write_gs_request
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_request.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_REQUEST';
      for x in ( select rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( staffid ), null, ' ', redaction_pkg.c_mask ), 10, ' ' ) staffid,
			rpad ( decode ( request_date, null, ' ', to_char ( request_date, 'DD-MON-YYYY' ) ), 11, ' ' ) request_date,
			rpad ( decode ( receive_date, null, ' ', to_char ( receive_date, 'DD-MON-YYYY' ) ), 11, ' ' ) receive_date,
			rpad ( decode ( return_date, null, ' ', to_char ( return_date, 'DD-MON-YYYY' ) ), 11, ' ' ) return_date,
			rpad ( decode ( store_num, null, ' ', redaction_pkg.c_mask ), 20, ' ' ) store_num,
			rpad ( decode ( boxid, null, ' ', boxid ), 9, ' ' ) boxid,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_request
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.staffid );
	  utl_file.put ( redaction_pkg.v_file_header, x.request_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.receive_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.return_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.store_num );
	  utl_file.put ( redaction_pkg.v_file_header, x.boxid );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_request;
    procedure write_gs_restitution is
    -- pre:  data in GS_RESTITUTION is expunged
    -- post:  ASCII file table_gs_restitution.txt written to OS directory in file format specified by requirements
    begin -- write_gs_restitution
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_restitution.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_RESTITUTION';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( to_char ( victimid ), null, ' ', to_char ( victimid ) ), 10, ' ' ) victimid,
			rpad ( decode ( type, null, ' ', type ), 1, ' ' ) type,
			rpad ( decode ( recipient, null, ' ', recipient ), 1, ' ' ) recipient,
			rpad ( decode ( to_char ( amount ), null, ' ', to_char ( amount ) ), 14, ' ' ) amount,
			rpad ( decode ( liability, null, ' ', liability ), 1, ' ' ) liability,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_restitution
                  order by district, caseid
               ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.victimid );
	  utl_file.put ( redaction_pkg.v_file_header, x.type );
	  utl_file.put ( redaction_pkg.v_file_header, x.recipient );
	  utl_file.put ( redaction_pkg.v_file_header, x.amount );
	  utl_file.put ( redaction_pkg.v_file_header, x.liability );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_restitution;
/*  procedure write_gs_sec_case_staff_group is
    -- pre:  data in GS_SEC_CASE_STAFF_GROUP is expunged
    -- post:  ASCII file table_gs_sec_case_staff_group.txt written to OS directory in file format specified by requirements
    begin -- write_gs_sec_case_staff_group
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_sec_case_staff_group.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_SEC_CASE_STAFF_GROUP';
      for x in ( select rpad ( decode ( to_char ( id ), null, ' ', redaction_pkg.c_mask ), 22, ' ' ) id,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( caseid, null, ' ', redaction_pkg.c_mask ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( staffgroupid ), null, ' ', redaction_pkg.c_mask ), 22, ' ' ) staffgroupid
                   from gs_sec_case_staff_group
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.staffgroupid );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_sec_case_staff_group;
*/
    procedure write_gs_dna is
    -- pre:  data in GS_DNA is expunged
    -- post:  ASCII file gs_dna.txt written to OS directory in file format specified by requirements
    begin -- write_gs_dna
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_dna.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_DNA';
       for x in ( select rpad ( decode ( district, null, ' ', district ), 3, ' ' ) district,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( proceedings_aft_relief_granted, null, ' ', proceedings_aft_relief_granted ), 1, ' ' ) proceedings_aft_relief_granted,
			rpad ( decode ( new_trial_ord, null, ' ', new_trial_ord ), 1, ' ' ) new_trial_ord,
			rpad ( decode ( charge_dismissed, null, ' ', charge_dismissed ), 1, ' ' ) charge_dismissed,
                        rpad ( decode ( found_guilty, null, ' ', found_guilty ), 1, ' ' ) found_guilty,
			rpad ( decode ( guilty_plea_entered, null, ' ', guilty_plea_entered ), 1, ' ' ) guilty_plea_entered,
			rpad ( decode ( acquitted, null, ' ', acquitted ), 1, ' ' ) acquitted,
			rpad ( decode ( resentencing_cap_case, null, ' ', resentencing_cap_case ), 1, ' ' ) resentencing_cap_case,
			rpad ( decode ( testing_ordered, null, ' ', testing_ordered ), 1, ' ' ) testing_ordered,
			rpad ( decode ( relief_granted, null, ' ', relief_granted ), 1, ' ' ) relief_granted,
			rpad ( decode ( comments, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) comments,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_dna
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
	  utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.proceedings_aft_relief_granted );
	  utl_file.put ( redaction_pkg.v_file_header, x.new_trial_ord );
	  utl_file.put ( redaction_pkg.v_file_header, x.charge_dismissed );
	  utl_file.put ( redaction_pkg.v_file_header, x.found_guilty );
	  utl_file.put ( redaction_pkg.v_file_header, x.guilty_plea_entered );
	  utl_file.put ( redaction_pkg.v_file_header, x.acquitted );
	  utl_file.put ( redaction_pkg.v_file_header, x.resentencing_cap_case );
	  utl_file.put ( redaction_pkg.v_file_header, x.testing_ordered );
	  utl_file.put ( redaction_pkg.v_file_header, x.relief_granted );
	  utl_file.put ( redaction_pkg.v_file_header, x.comments );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_dna;
    procedure write_gs_sentence is
    -- pre:  data in GS_SENTENCE is expunged and redacted
    -- post:  ASCII file table_gs_sentence.txt written to OS directory in file format specified by requirements
    begin -- write_gs_sentence
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_sentence.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_SENTENCE';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
                        rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
                        rpad ( decode ( partid, null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( sent_date, null, ' ',
                                                   to_char ( sent_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sent_date,
                        rpad ( decode ( guide_depart, null, ' ', guide_depart ), 1, ' ' ) guide_depart,
                        rpad ( decode ( incar_type, null, ' ', incar_type ), 3, ' ' ) incar_type,
                        rpad ( decode ( judgeid, null, ' ', to_char ( judgeid ) ), 10, ' ' ) judgeid,
                        rpad ( decode ( prob_days, null, ' ', to_char ( prob_days ) ), 11, ' ' ) prob_days,
                        rpad ( decode ( prob_months, null, ' ', to_char ( prob_months ) ), 11, ' ' ) prob_months,
                        rpad ( decode ( prob_years, null, ' ', to_char ( prob_years ) ), 11, ' ' ) prob_years,
                        rpad ( decode ( super_rel_days, null, ' ', to_char ( super_rel_days ) ), 11, ' ' ) super_rel_days,
                        rpad ( decode ( super_rel_months, null, ' ', to_char ( super_rel_months ) ), 11, ' ' ) super_rel_months,
                        rpad ( decode ( super_rel_years, null, ' ', to_char ( super_rel_years ) ), 11, ' ' ) super_rel_years,
                        rpad ( decode ( incar_days, null, ' ', to_char ( incar_days ) ), 11, ' ' ) incar_days,
                        rpad ( decode ( incar_months, null, ' ', to_char ( incar_months ) ), 11, ' ' ) incar_months,
                        rpad ( decode ( incar_years, null, ' ', to_char ( incar_years ) ), 11, ' ' ) incar_years,
                        rpad ( decode ( fine, null, ' ', to_char ( fine ) ), 14, ' ' ) fine,
                        rpad ( decode ( spec_assessment, null, ' ', to_char ( spec_assessment ) ), 14, ' ' ) spec_assessment,
                        rpad ( decode ( debarred, null, ' ', debarred ), 1, ' ' ) debarred,
                        rpad ( decode ( spec_condition, null, ' ', spec_condition ), 4, ' ' ) spec_condition,
                        rpad ( decode ( probation_revoked, null, ' ', probation_revoked ), 1, ' ' ) probation_revoked,
                        rpad ( decode ( super_rel_revoked, null, ' ', super_rel_revoked ), 1, ' ' ) super_rel_revoked,
                        rpad ( decode ( total_revoked_days, null, ' ', to_char ( total_revoked_days ) ), 11, ' ' ) total_revoked_days,
                        rpad ( decode ( total_revoked_months, null, ' ', to_char ( total_revoked_months ) ), 11, ' ' ) total_revoked_months,
                        rpad ( decode ( total_revoked_years, null, ' ', to_char ( total_revoked_years ) ), 11, ' ' ) total_revoked_years,
                        rpad ( decode ( related_flu_usao, null, ' ', related_flu_usao ), 10, ' ' ) related_flu_usao,
                        rpad ( decode ( related_flu_seq, null, ' ', related_flu_seq ), 3, ' ' ) related_flu_seq,
                        rpad ( decode ( comm_serv_hours, null, ' ', to_char ( comm_serv_hours ) ), 12, ' ' ) comm_serv_hours,
                        rpad ( decode ( sys_sent_date, null, ' ',
                                                       to_char ( sys_sent_date, 'DD-MON-YYYY' ) ), 11, ' ' ) sys_sent_date,
                        rpad ( decode ( restitution_amt, null, ' ', to_char ( restitution_amt ) ), 16, ' ' ) restitution_amt,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user,
                        rpad ( decode ( supv_rel_incar_type, null, ' ', supv_rel_incar_type ), 1, ' ' ) supv_rel_incar_type
                   from gs_sentence
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.sent_date );
          utl_file.put ( redaction_pkg.v_file_header, x.guide_depart );
          utl_file.put ( redaction_pkg.v_file_header, x.incar_type );
          utl_file.put ( redaction_pkg.v_file_header, x.judgeid );
          utl_file.put ( redaction_pkg.v_file_header, x.prob_days );
          utl_file.put ( redaction_pkg.v_file_header, x.prob_months );
          utl_file.put ( redaction_pkg.v_file_header, x.prob_years );
          utl_file.put ( redaction_pkg.v_file_header, x.super_rel_days );
          utl_file.put ( redaction_pkg.v_file_header, x.super_rel_months );
          utl_file.put ( redaction_pkg.v_file_header, x.super_rel_years );
          utl_file.put ( redaction_pkg.v_file_header, x.incar_days );
          utl_file.put ( redaction_pkg.v_file_header, x.incar_months );
          utl_file.put ( redaction_pkg.v_file_header, x.incar_years );
          utl_file.put ( redaction_pkg.v_file_header, x.fine );
          utl_file.put ( redaction_pkg.v_file_header, x.spec_assessment );
          utl_file.put ( redaction_pkg.v_file_header, x.debarred );
          utl_file.put ( redaction_pkg.v_file_header, x.spec_condition );
          utl_file.put ( redaction_pkg.v_file_header, x.probation_revoked );
          utl_file.put ( redaction_pkg.v_file_header, x.super_rel_revoked );
          utl_file.put ( redaction_pkg.v_file_header, x.total_revoked_days );
          utl_file.put ( redaction_pkg.v_file_header, x.total_revoked_months );
          utl_file.put ( redaction_pkg.v_file_header, x.total_revoked_years );
          utl_file.put ( redaction_pkg.v_file_header, x.related_flu_usao );
          utl_file.put ( redaction_pkg.v_file_header, x.related_flu_seq );
          utl_file.put ( redaction_pkg.v_file_header, x.comm_serv_hours );
          utl_file.put ( redaction_pkg.v_file_header, x.sys_sent_date );
          utl_file.put ( redaction_pkg.v_file_header, x.restitution_amt );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          utl_file.put ( redaction_pkg.v_file_header, x.supv_rel_incar_type );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_sentence;
    procedure write_gs_staff is
    -- pre:  data in gs_staff is expunged
    -- post:  ASCII file table_gs_staff.txt written to OS directory in file format specified by requirements
    begin -- write_gs_staff
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_staff.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_STAFF';
      for x in ( select rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( username, null, ' ', redaction_pkg.c_mask ), 18, ' ' ) username,
			rpad ( decode ( initials, null, ' ', initials ), 8, ' ' ) initials,
			rpad ( decode ( init_stat, null, ' ', init_stat ), 1, ' ' ) init_stat,
			rpad ( decode ( staff_title, null, ' ', staff_title ), 3, ' ' ) staff_title,
			rpad ( decode ( salutation, null, ' ', salutation ), 8, ' ' ) salutation,
			rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) last_name,
			rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
			rpad ( decode ( office_loc, null, ' ', office_loc ), 30, ' ' ) office_loc,
			rpad ( decode ( phone, null, ' ', redaction_pkg.c_mask ), 15, ' ' ) phone,
			rpad ( decode ( issued_date, null, ' ', to_char ( issued_date, 'DD-MON-YYYY' ) ), 11, ' ' ) issued_date,
			rpad ( decode ( default_dir, null, ' ', redaction_pkg.c_mask ), 40, ' ' ) default_dir,
			rpad ( decode ( default_print, null, ' ', redaction_pkg.c_mask ), 40, ' ' ) default_print,
			rpad ( decode ( default_dc_loc, null, ' ', default_dc_loc ), 2, ' ' ) default_dc_loc,
			rpad ( decode ( default_branch, null, ' ', default_branch ), 3, ' ' ) default_branch,
			rpad ( decode ( name_search, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) name_search,
			rpad ( decode ( staff_sec_type, null, ' ', redaction_pkg.c_mask ), 1, ' ' ) staff_sec_type,
			rpad ( decode ( staff_section, null, ' ', staff_section ), 8, ' ' ) staff_section,
			rpad ( decode ( district, null, ' ', district ), 3, ' ' ) district,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user,
			rpad ( decode ( AD_USERNAME, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) AD_USERNAME,
			rpad ( decode ( LCMS_POSITION, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) LCMS_POSITION,
			rpad ( decode ( CASE_TYPE, null, ' ', CASE_TYPE ), 10, ' ' ) CASE_TYPE,
			rpad ( decode ( ACTION_STAGE, null, ' ', ACTION_STAGE ), 10, ' ' ) ACTION_STAGE,
			rpad ( decode ( DR_USERNAME, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) DR_USERNAME,
			rpad ( decode ( GUID, null, ' ', GUID ), 30, ' ' ) GUID
                   from gs_staff
                  order by district, id ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.username );
	  utl_file.put ( redaction_pkg.v_file_header, x.initials );
	  utl_file.put ( redaction_pkg.v_file_header, x.init_stat );
	  utl_file.put ( redaction_pkg.v_file_header, x.staff_title );
	  utl_file.put ( redaction_pkg.v_file_header, x.salutation );
	  utl_file.put ( redaction_pkg.v_file_header, x.last_name );
	  utl_file.put ( redaction_pkg.v_file_header, x.first_name );
	  utl_file.put ( redaction_pkg.v_file_header, x.office_loc );
	  utl_file.put ( redaction_pkg.v_file_header, x.phone );
	  utl_file.put ( redaction_pkg.v_file_header, x.issued_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.default_dir );
	  utl_file.put ( redaction_pkg.v_file_header, x.default_print );
	  utl_file.put ( redaction_pkg.v_file_header, x.default_dc_loc );
	  utl_file.put ( redaction_pkg.v_file_header, x.default_branch );
	  utl_file.put ( redaction_pkg.v_file_header, x.name_search );
	  utl_file.put ( redaction_pkg.v_file_header, x.staff_sec_type );
	  utl_file.put ( redaction_pkg.v_file_header, x.staff_section );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.AD_USERNAME );
	  utl_file.put ( redaction_pkg.v_file_header, x.LCMS_POSITION );
	  utl_file.put ( redaction_pkg.v_file_header, x.CASE_TYPE );
	  utl_file.put ( redaction_pkg.v_file_header, x.ACTION_STAGE );
	  utl_file.put ( redaction_pkg.v_file_header, x.DR_USERNAME );
	  utl_file.put ( redaction_pkg.v_file_header, x.GUID );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_staff;
--
    procedure write_gs_court_order_disp is
    -- pre:  data in gs_court_order_disp is expunged
    -- post:  ASCII file table_gs_court_order_disp.txt written to OS directory in file format specified by requirements
    begin -- write_gs_court_order_disp
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_court_order_disp.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_COURT_ORDER_DISP';
      for x in ( select rpad ( decode ( district, null, ' ', district ), 3, ' ' ) district,
			rpad ( decode ( to_char ( id ), null, ' ', to_char ( id ) ), 10, ' ' ) id,
			rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( crthisid ), null, ' ', to_char ( crthisid ) ), 10, ' ' ) crthisid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
                        rpad ( decode ( code, null, ' ', code ), 4, ' ' ) code,
			rpad ( decode ( system_date, null, ' ', to_char ( system_date, 'DD-MON-YYYY' ) ), 11, ' ' ) system_date,
			rpad ( decode ( date_of_order, null, ' ', to_char ( date_of_order, 'DD-MON-YYYY' ) ), 11, ' ' ) date_of_order,
                        rpad ( decode ( last_name, null, ' ', redaction_pkg.c_mask ), 60, ' ' ) last_name,
                        rpad ( decode ( first_name, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) first_name,
                        rpad ( decode ( court, null, ' ', court ), 4, ' ' ) court,
                        rpad ( decode ( court_number, null, ' ', redaction_pkg.c_mask ), 25, ' ' ) court_number,
			rpad ( decode ( to_char ( partid2 ), null, ' ', to_char ( partid2 ) ), 10, ' ' ) partid2,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_court_order_disp
                  where code = 'SEAL'
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.id );
	  utl_file.put ( redaction_pkg.v_file_header, x.caseid );
	  utl_file.put ( redaction_pkg.v_file_header, x.crthisid );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid );
	  utl_file.put ( redaction_pkg.v_file_header, x.code );
	  utl_file.put ( redaction_pkg.v_file_header, x.system_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.date_of_order );
	  utl_file.put ( redaction_pkg.v_file_header, x.last_name );
	  utl_file.put ( redaction_pkg.v_file_header, x.first_name );
	  utl_file.put ( redaction_pkg.v_file_header, x.court );
	  utl_file.put ( redaction_pkg.v_file_header, x.court_number );
	  utl_file.put ( redaction_pkg.v_file_header, x.partid2 );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_court_order_disp;
--
    procedure write_gs_triggerlock is
    -- pre:  data in GS_TRIGGERLOCK is expunged
    -- post:  ASCII file table_gs_triggerlock.txt written to OS directory in file format specified by requirements
    begin -- write_gs_triggerlock
      redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                        'gs_triggerlock.txt',
                                        'w',
                                        redaction_pkg.c_linesize );
      redaction_pkg.v_count := 0;
      redaction_pkg.v_district := null;
      redaction_pkg.v_caseid := null;
      redaction_pkg.v_partid := null;
      redaction_pkg.v_table_name := 'GS_TRIGGERLOCK';
      for x in ( select rpad ( decode ( caseid, null, ' ', caseid ), 10, ' ' ) caseid,
			rpad ( decode ( to_char ( partid ), null, ' ', to_char ( partid ) ), 10, ' ' ) partid,
			rpad ( decode ( district, null, ' ', district ), 10, ' ' ) district,
			rpad ( decode ( brady_offense, null, ' ', brady_offense ), 1, ' ' ) brady_offense,
			rpad ( decode ( notice_3_strikes, null, ' ', notice_3_strikes ), 1, ' ' ) notice_3_strikes,
			rpad ( decode ( date_notice_filed, null, ' ', to_char ( date_notice_filed, 'DD-MON-YYYY' ) ), 11, ' ' ) date_notice_filed,
			rpad ( decode ( date_notice_withdrawn, null, ' ', to_char ( date_notice_withdrawn, 'DD-MON-YYYY' ) ), 11, ' ' ) date_notice_withdrawn,
			rpad ( decode ( withdrawal_reason, null, ' ', redaction_pkg.c_mask ), 78, ' ' ) withdrawal_reason,
			rpad ( decode ( conviction_3_strikes, null, ' ', conviction_3_strikes ), 1, ' ') conviction_3_strikes,
			rpad ( decode ( life_3_strikes, null, ' ', life_3_strikes ), 1, ' ' ) life_3_strikes,
			rpad ( decode ( no_life_reason, null, ' ', redaction_pkg.c_mask ), 78, ' ' ) no_life_reason,
			rpad ( decode ( third_prosec_trigg_offense, null, ' ', third_prosec_trigg_offense ), 1, ' ' ) third_prosec_trigg_offense,
			rpad ( decode ( triggerlock_def, null, ' ', triggerlock_def ), 1, ' ' ) triggerlock_def,
			rpad ( decode ( bailey_sentence_change, null, ' ', bailey_sentence_change ), 1, ' ' ) bailey_sentence_change,
			rpad ( decode ( to_char ( sentence_prior_bailey ), null, ' ', to_char ( sentence_prior_bailey ) ), 11, ' ' ) sentence_prior_bailey,
			rpad ( decode ( armed_career_criminal, null, ' ', armed_career_criminal ), 1, ' ' ) armed_career_criminal,
			rpad ( decode ( create_date, null, ' ', to_char ( create_date, 'DD-MON-YYYY' ) ), 11, ' ' ) create_date,
			rpad ( decode ( create_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) create_user,
			rpad ( decode ( update_date, null, ' ', to_char ( update_date, 'DD-MON-YYYY' ) ), 11, ' ' ) update_date,
			rpad ( decode ( update_user, null, ' ', redaction_pkg.c_mask ), 30, ' ' ) update_user
                   from gs_triggerlock
                  order by district, caseid ) loop
        begin -- exception handling block
          redaction_pkg.v_district := substr ( x.district, 1, 3 );
          redaction_pkg.v_caseid := x.caseid;
          redaction_pkg.v_partid := x.partid;
          utl_file.put ( redaction_pkg.v_file_header, x.district );
          utl_file.put ( redaction_pkg.v_file_header, x.caseid );
          utl_file.put ( redaction_pkg.v_file_header, x.partid );
          utl_file.put ( redaction_pkg.v_file_header, x.brady_offense );
          utl_file.put ( redaction_pkg.v_file_header, x.notice_3_strikes );
          utl_file.put ( redaction_pkg.v_file_header, x.date_notice_filed );
          utl_file.put ( redaction_pkg.v_file_header, x.date_notice_withdrawn );
          utl_file.put ( redaction_pkg.v_file_header, x.withdrawal_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.conviction_3_strikes );
          utl_file.put ( redaction_pkg.v_file_header, x.life_3_strikes );
          utl_file.put ( redaction_pkg.v_file_header, x.no_life_reason );
          utl_file.put ( redaction_pkg.v_file_header, x.third_prosec_trigg_offense );
          utl_file.put ( redaction_pkg.v_file_header, x.triggerlock_def );
          utl_file.put ( redaction_pkg.v_file_header, x.bailey_sentence_change );
          utl_file.put ( redaction_pkg.v_file_header, x.sentence_prior_bailey );
          utl_file.put ( redaction_pkg.v_file_header, x.armed_career_criminal );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.create_user );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_date );
	  utl_file.put ( redaction_pkg.v_file_header, x.update_user );
          -- carriage return to the next line
          utl_file.new_line ( redaction_pkg.v_file_header );
          redaction_pkg.v_count := redaction_pkg.v_count + 1;
        exception
          when others then
            redaction_pkg.write_error;
        end; -- exception handling block
      end loop;
      utl_file.fclose ( redaction_pkg.v_file_header );
      redaction_pkg.log_record_count ( redaction_pkg.v_process_name, redaction_pkg.v_table_name, redaction_pkg.v_count );
    exception
      when others then
        redaction_pkg.write_error;
    end write_gs_triggerlock;
  begin
    redaction_pkg.v_process_name := 'WRITE';
    write_gs_case;
    write_gs_agent;
    write_gs_also_known;
    write_gs_archive_case;
    write_gs_archive_part;
    write_gs_assignment;
    write_gs_case_cause_act;
    write_gs_case_doj_div;
    write_gs_case_dom_terr_ind;
    write_gs_case_prog_cat;
    write_gs_case_special_proj;
    write_gs_comment;
    write_gs_cont_services;
    write_gs_contact_log;
    write_gs_control_sub;
    write_gs_count;
    write_gs_court_hist;
    write_gs_court_judge;
    write_gs_court_order_disp;
    write_gs_defend_stat;
    write_gs_dna;
    write_gs_event;
    write_gs_evidence;
    write_gs_expert_case;
    write_gs_inst_charge;
    write_gs_instrument;
    write_gs_oppose_coun;
    write_gs_part_count;
    write_gs_part_court;
    write_gs_part_event;
    write_gs_part_relief;
    write_gs_part_victim;
    write_gs_participant;
    write_gs_prop_value;
    write_gs_region;
    write_gs_relate_appeal;
    write_gs_relate_case;
    write_gs_relate_part;
    write_gs_relief;
    write_gs_request;
    write_gs_restitution;
--  write_gs_sec_case_staff_group;
    write_gs_sentence;
    write_gs_staff;
    write_gs_triggerlock;
    commit;
  end write_tables;
  procedure generate_report ( p_date  IN varchar2 ) IS
  -- pre: expunged and redaction process is complete
  -- post: text file written with record counts for each table at various stages of the process
    v_imported  number;
    v_prior     number;
    v_delete    number;
    v_write     number;
    v_total     number := 0;
    v_gs_part   varchar2 ( 1 ) := 'N';
  begin -- main
    redaction_pkg.v_process_name := 'REPORT';
    redaction_pkg.v_district := null;
    redaction_pkg.v_table_name := NULL;
    redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                      p_date || '.txt',
                                      'w',
                                      redaction_pkg.c_linesize );
    for x in ( select distinct table_name
                 from nl_monthly_counts
                order by table_name ) loop
      v_imported := 0;
      v_prior := 0;
      v_delete := 0;
      v_write := 0;
      begin -- exception handling block
        -- v_gs_part is a flag indicating if we are processing the gs_participant or gs_event tables' record counts
        -- if the table name is like gs_participant and the flag is N, we are processing it for the first time
        -- so we set the flag to Y, pull the imported and deleted counts from the table and output to file
        -- otherwise, if it's a non gs_participant(event) table, we just get the counts
        dbms_output.put_line ( x.table_name || ' ' || v_gs_part );
        if x.table_name in ( 'GS_PARTICIPANT', 'GS_EVENT', 'GS_PART_EVENT' ) then
          v_gs_part := 'Y';
          select record_count
            into v_imported
           from nl_monthly_counts
          where process_name = 'IMPORTED' and
                table_name = x.table_name;
          select sum ( record_count )
            into v_delete
           from nl_monthly_counts
          where process_name in ( 'MARKED_EXPUNGED', 'SEALED_CIVIL' ) and
                table_name = x.table_name;
          utl_file.put_line ( redaction_pkg.v_file_header, '******************************************************' );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Table name - ' || x.table_name );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Number of records imported:              ' || lpad ( to_char ( v_imported ), 12, ' ' ) );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Marked and sealed civil records deleted: ' || lpad ( '-' || to_char ( v_delete ), 12, ' ' ) );
        end if;
        if x.table_name not like 'GS_PARTICIPANT%' and
           x.table_name not like 'GS_PART_EVENT%' and
           x.table_name not like 'GS_EVENT%' then
          -- we are done processing participants so we need to output the total
          if v_gs_part = 'Y' then
            v_gs_part := 'N';
            utl_file.put_line ( redaction_pkg.v_file_header, 'Total number of records written to file:       ' || lpad ( to_char ( v_total ), 27, ' ' ) );
            utl_file.new_line ( redaction_pkg.v_file_header );
            v_total := 0;
          end if;
          select record_count
            into v_imported
           from nl_monthly_counts
          where process_name = 'IMPORTED' and
                table_name = x.table_name;
          select sum ( record_count )
            into v_delete
           from nl_monthly_counts
          where process_name in ( 'MARKED_EXPUNGED', 'SEALED_CIVIL' ) and
                table_name = x.table_name;
        end if;
        if x.table_name not in ( 'GS_PARTICIPANT', 'GS_EVENT', 'GS_PART_EVENT' ) THEN
          select record_count
            into v_write
           from nl_monthly_counts
          where process_name = 'WRITE' and
                table_name = x.table_name;
        end if;
        if x.table_name like 'GS_PARTICIPANT_%' or
           x.table_name like 'GS_PART_EVENT_%' or
           x.table_name like 'GS_EVENT_%' then
          utl_file.put_line ( redaction_pkg.v_file_header, 'Number of records written to file ' ||
                                                           rpad ( x.table_name, 20, ' ' ) ||
                                                           ':       ' ||
                                                           lpad ( to_char ( v_write ), 12, ' ' ) );
          -- tally participant or event count for each individual district
          v_total := v_write + v_total;
        elsif x.table_name not in ( 'GS_PARTICIPANT', 'GS_EVENT', 'GS_PART_EVENT' ) then
          utl_file.put_line ( redaction_pkg.v_file_header, '******************************************************' );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Table name - ' || x.table_name );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Number of records imported:              ' || lpad ( to_char ( v_imported ), 12, ' ' ) );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Marked and sealed civil records deleted: ' || lpad ( '-' || to_char ( nvl ( v_delete, 0 ) ), 12, ' ' ) );
          utl_file.put_line ( redaction_pkg.v_file_header, 'Number of records written to file:       ' || lpad ( to_char ( v_write ), 12, ' ' ) );
          utl_file.new_line ( redaction_pkg.v_file_header );
        end if;
      exception
        when others then
          redaction_pkg.write_error;
      end; -- exception handling block
    end loop;
    utl_file.put_line ( redaction_pkg.v_file_header, '******************************************************' );
    utl_file.fclose ( redaction_pkg.v_file_header );
    exception
      when others then
        redaction_pkg.write_error;
  end generate_report;
  procedure generate_error_log ( p_date  IN varchar2 ) IS
  -- pre: expunged and redaction process is complete
  -- post: text file written with errors encountered
  begin -- generate_error_log
    redaction_pkg.v_process_name := 'ERROR_LOG';
    redaction_pkg.v_district := null;
    redaction_pkg.v_table_name := NULL;
    redaction_pkg.v_count := 0;
    redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                      p_date || '.err',
                                      'w',
                                      redaction_pkg.c_linesize );
    for x in ( select *
                 from nl_error_log ) loop
      begin -- exception handling block
        utl_file.put_line ( redaction_pkg.v_file_header, '******************************************************' );
        utl_file.put_line ( redaction_pkg.v_file_header, to_char ( x.id ) || '.  ' || x.process_name );
        utl_file.put_line ( redaction_pkg.v_file_header, 'Table Name: ' || x.table_name );
        utl_file.put_line ( redaction_pkg.v_file_header, 'District/Caseid: ' || nvl ( x.district, 'NA' ) || '/' || nvl ( x.caseid, 'NA' ) );
        utl_file.put_line ( redaction_pkg.v_file_header, 'Partid: ' || to_char ( x.partid ) );
        utl_file.put_line ( redaction_pkg.v_file_header, 'Error Number: ' || x.error_nbr );
        utl_file.put_line ( redaction_pkg.v_file_header, 'Error Message: ' || x.error_msg );
        utl_file.put_line ( redaction_pkg.v_file_header, '******************************************************' );
        utl_file.new_line ( redaction_pkg.v_file_header );
        redaction_pkg.v_count := redaction_pkg.v_count + 1;
      exception
        when others then
          redaction_pkg.write_error;
      end; -- exception handling block
    end loop;
    utl_file.put_line ( redaction_pkg.v_file_header, to_char ( redaction_pkg.v_count ) || ' errors encountered during ' || p_date || ' redaction.' );
    utl_file.fclose ( redaction_pkg.v_file_header );
    exception
      when others then
        redaction_pkg.write_error;
  end generate_error_log;
  procedure generate_temp_table_log ( p_date  IN varchar2 ) is
  -- pre: expunged and redaction process is complete
  -- post: text file written with contents of NL_ tables, excluding expunge tables
  begin -- generate_temp_table_log;
    redaction_pkg.v_process_name := 'AUDIT_LOG';
    redaction_pkg.v_district := null;
    redaction_pkg.v_table_name := NULL;
    redaction_pkg.v_count := 0;
    redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                      p_date || '_nl_monthly_counts.log',
                                      'w',
                                      redaction_pkg.c_linesize );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        'Process Name                   Table Name                     Record Count' );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        '------------------------------ ------------------------------ ------------------------------' );
    for x in ( select rpad ( process_name, 30, ' ' ) process_name,
                      rpad ( table_name, 30, ' ' ) table_name,
                      rpad ( record_count, 30, ' ' ) record_count
                 from nl_monthly_counts ) loop
      begin -- exception handling block
        utl_file.put ( redaction_pkg.v_file_header, x.process_name );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.table_name );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.record_count );
        utl_file.new_line ( redaction_pkg.v_file_header );
      exception
        when others then
          redaction_pkg.write_error;
      end; -- exception handling block
    end loop;
    utl_file.fclose ( redaction_pkg.v_file_header );
    redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                      p_date || '_nl_redacted_cases_log.log',
                                      'w',
                                      redaction_pkg.c_linesize );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        'Process Name                   District Caseid' );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        '------------------------------ -------- ----------' );
    for x in ( select rpad ( process_name, 30, ' ' ) process_name,
                      rpad ( district, 8, ' ' ) district,
                      caseid
                 from nl_redacted_cases_log ) loop
      begin -- exception handling block
        utl_file.put ( redaction_pkg.v_file_header, x.process_name );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.district );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.caseid );
        utl_file.new_line ( redaction_pkg.v_file_header );
      exception
        when others then
          redaction_pkg.write_error;
      end; -- exception handling block
    end loop;
    utl_file.fclose ( redaction_pkg.v_file_header );
    redaction_pkg.v_file_header := utl_file.fopen ( redaction_pkg.v_write_location,
                                      p_date || '_nl_redacted_participants_log.log',
                                      'w',
                                      redaction_pkg.c_linesize );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        'Process Name                   District Caseid     Partid' );
    utl_file.put_line ( redaction_pkg.v_file_header,
                        '------------------------------ -------- ---------- -----------' );
    for x in ( select rpad ( process_name, 30, ' ' ) process_name,
                      rpad ( district, 8, ' ' ) district,
                      caseid, partid
                 from nl_redacted_participants_log ) loop
      begin -- exception handling block
        utl_file.put ( redaction_pkg.v_file_header, x.process_name );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.district );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, x.caseid );
        utl_file.put ( redaction_pkg.v_file_header, ' ' );
        utl_file.put ( redaction_pkg.v_file_header, to_char ( x.partid ) );
        utl_file.new_line ( redaction_pkg.v_file_header );
      exception
        when others then
          redaction_pkg.write_error;
      end; -- exception handling block
    end loop;
    utl_file.fclose ( redaction_pkg.v_file_header );
  end generate_temp_table_log;
  procedure main ( p_run_date  IN varchar2 ) is
  begin -- main
    write_tables;
    if redaction_pkg.error_check = 0 then
      generate_report ( p_run_date );
    end if;
    generate_temp_table_log ( p_run_date );
    generate_error_log ( p_run_date );
  end main;
end nl_trac_extract;
/
sho err
spool off
set echo off